library(readr)
library(dplyr)
library(tidyr)
library(stringr)
library(ggplot2)

active_acc <- data %>%
  filter(countrynewwb == "India" &  year %in% c(2021, 2024), group == "gender") %>%
  select(countrynewwb, year, group2, ts_account, ts_dormant_FI_imputed) %>%
  filter(!is.na(ts_account)) %>%
  mutate(
    gap1 = ts_account - ts_dormant_FI_imputed,
    gap2 = ts_dormant_FI_imputed,
    total = ts_account
  ) %>%
  gather(group, value, gap1, gap2) %>%
  filter(!is.na(group), !is.na(value)) %>%
  mutate(
    total = total * 100,
    value = value * 100,
    lab = ifelse(group == "gap1", round(total), NA)
  ) %>%
  filter(!is.na(total)) 
# %>%
#   mutate(countrynewwb = recode(countrynewwb, 
#                                "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
#                                         "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
#                                         "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
#                                         "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
#                                         "South Asia (excluding high income)" = "South Asia",
#                                         "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"
#   ))

length_unique_countries <- active_acc %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Calculate width and height based on unique countries
if (length_unique_countries < 8) {
  width_num <- 8
  height_num <- 4
} else {
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

# Check max value for y-axis
max_val <- max(active_acc$total, na.rm = TRUE) + 15
if (max_val > 92) {
  max_val <- 110
}

# Create the plot
ggplot(active_acc) +
  geom_bar(
    aes(
      x = fct_rev(group2),
      y = value,
      fill = factor(group, levels = c("gap2", "gap1"))
    ),
    stat = "identity",
    position = "stack",
    width = 0.75,
    color = "black"
  ) +
  scale_fill_manual(
    values = c("gap1" = "#0F72BC", "gap2" = "#B8CB33"),
    breaks = c("gap1", "gap2"),
    labels = c(
      "Have an active account",
      "Have an inactive bank account and no mobile money account"
    )
  ) +
  scale_y_continuous(
    limits = c(0, max_val),
    breaks = seq(0, max_val, by = 20)
  ) +
  scale_x_discrete(labels = function(x) str_wrap(x, width = 10)) +
  facet_grid(
    . ~ year,
    scales = "free",
    space = "free",
    switch = "both",
    labeller = label_wrap_gen(width = 10, multi_line = TRUE)
  ) +
  theme(
    strip.placement = "outside",
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = "center",
    strip.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    strip.text.y = element_text(family = "Nunito Sans", color = "black", size = 16, hjust = 0),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16, hjust = 0),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_line(color = "black"),
    plot.subtitle = element_text(size = 16, family = "Nunito Sans"),
    plot.title = element_text(
      hjust = 0,
      size = 16,
      family = "Nunito Sans",
      face = "bold"
    ),
    plot.title.position = "plot",
    legend.text = element_text(size = 16, family = "Nunito Sans"),
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 2, byrow = TRUE)) +
  labs(
    caption = "Source: Global Findex Database 2025",
    subtitle = "Adults with an account (%), 2024",
    title = "Active accounts in India"
  )

# Save the plot
ggsave(
  filename = file.path(folder_path, sprintf("S3.3.1.png")),
  width = 8,
  height = 5,
  device = 'png',
  dpi = 120
)

# ggsave(
#   filename = file.path(folder_path, sprintf("3.3.15.eps")),
#   width = 7,
#   height = 5,
#   device = 'eps',
#   dpi = 120
# )
