library(dplyr)
library(ggplot2)
library(showtext)

# Load Nunito Sans font from Google Fonts
# font_add_google("Nunito Sans", "Nunito Sans")
# showtext_auto()

# Define income groups to keep
selected_income_groups <- c("Low income", "Lower middle income", "Upper middle income", "High income")

# Prepare data
dot_data <- data %>%
  filter(year == 2024, group == "all") %>%
  filter(countrynewwb %in% c_list_all) %>%
  filter(incomegroupwb24 %in% selected_income_groups) %>%
  select(countrynewwb, incomegroupwb24, ts_account) %>%
  mutate(ts_account = ts_account * 100) %>%
  filter(!is.na(ts_account), !is.na(incomegroupwb24))

# Reorder factor levels for y-axis
dot_data$incomegroupwb24 <- factor(dot_data$incomegroupwb24,
                                   levels = selected_income_groups)

dot_data$incomegroupwb24 <- recode(dot_data$incomegroupwb24,
                                   "Low income" = "Low-income economies",
                                   "Lower middle income" = "Lower-middle-income economies",
                                   "Upper middle income" = "Upper-middle-income economies",
                                   "High income" = "High-income economies")

# Define custom aqua blue-based color palette
income_colors <- c("Low-income economies" = "#B2D6F7",         # Light aqua blue
                   "Lower-middle-income economies" = "#5696D0", # Medium aqua blue
                   "Upper-middle-income economies" = "#5696D0", # Darker aqua blue
                   "High-income economies" = "#0F72BC")         # Dark Blue 

# Create dot plot with white-outlined dots
dot_plot <- ggplot(dot_data, aes(y = ts_account, x = incomegroupwb24)) +
  geom_point(size = 5, shape = 21, stroke = 0.75, aes(fill = incomegroupwb24), color = "black") +
  scale_fill_manual(values = income_colors) +
  scale_y_continuous(limits = c(0, 100), breaks = seq(0, 100, 20)) +
  coord_flip() +  # Flip axes
  theme_minimal(base_family = "Nunito Sans") +
  theme(
    strip.placement = "outside",
    plot.background = element_rect(fill = "white", color = NA),   
    panel.background = element_rect(fill = "white", color = NA), 
    strip.background  = element_rect(fill = "white", color = NA),
    panel.border = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(size = 14, color = "black"),
    axis.text.y = element_text(size = 14, hjust = 0, color = "black"),
    axis.ticks.x = element_line(color = "black"),
    legend.position = "none",
    plot.title = element_text(size = 16, face = "bold", hjust = 0, color = "black"),
    plot.subtitle = element_text(size = 14, hjust = 0, color = "black"),
    plot.title.position = "plot",
    plot.caption.position =  "plot",
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans")
  ) +
  labs(
    title = "Account ownership differs significantly even within income groups",
    subtitle = "Adults with an account (%), 2024",
    caption = "Source: Global Findex Database 2025"
    
  )

dot_plot

# Save the figure
ggsave(
  filename = file.path(folder_path, "figure_2_1_1.png"),
  plot = dot_plot,
  width = 8,
  height = 4,
  units = "in",
  device = "png",
  dpi = 120
)
