library(ggplot2)
library(dplyr)
library(tidyr)
library(ggrepel)

# Define countries to include
c_list_agg <- c("world", "High income", "LMIC")

# Filter dataset
total_agg <- data %>%
  filter(countrynewwb %in% c_list_agg,
         year %in% c(2011, 2014, 2017, 2021, 2024),
         group == "all") %>%
  select(countrynewwb, ts_account, year) %>%
  mutate(ts_account = ts_account * 100,
         year = as.factor(year)) %>%
  distinct()

# Define dynamic y-axis limits
y_limits <- total_agg %>%
  summarise(min_value = min(ts_account, na.rm = TRUE),
            max_value = max(ts_account, na.rm = TRUE))

y_min <- round(y_limits$min_value) - 5
y_max <- round(y_limits$max_value) + 10
if (y_max > 100) y_max <- 105
if (y_min < 0) y_min <- 0

# Nearest nice tick marks for axis
values_set <- c(0, 20, 40, 60, 80, 100)
find_nearest <- function(value, set) { set[which.min(abs(set - value))] }
nearest_max_value <- find_nearest(y_max, values_set)
nearest_min_value <- find_nearest(y_min, values_set)

# Color mapping
color_mapping <- c(
  "world" = "#8066AB",
  "High income" = "#0F72BC",
  "LMIC" = "#D12891"
)

# Legend labels
legend_labels <- c(
  "world" = "World",
  "High income" = "High-income economies",
  "LMIC" = "Low- and middle-income economies"
)

# Create the plot
ggplot(total_agg, aes(
  x = year,
  y = ts_account,
  color = factor(countrynewwb, levels = c("world", "High income", "LMIC")),
  group = countrynewwb
)) +
  geom_line(size = 1) +
  geom_point(size = 3) +
  geom_point(size = 3, shape = 1, color = "black") + 
  scale_x_discrete(breaks = c("2011", "2014", "2017", "2021", "2024")) +
  scale_y_continuous(
    limits = c(nearest_min_value, nearest_max_value),
    breaks = seq(nearest_min_value, nearest_max_value, by = 20)
  ) +
  scale_color_manual(values = color_mapping, labels = legend_labels) +
  theme_bw() +
  theme(
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.text = element_text(size = 16, family = "Nunito Sans"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(size = 16, family = "Nunito Sans", color = "black"),
    axis.text.y = element_text(size = 16, family = "Nunito Sans", color = "black"),
    plot.title = element_text(size = 16, family = "Nunito Sans", face = "bold"),
    plot.subtitle = element_text(size = 16, family = "Nunito Sans"),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    plot.caption.position =  "plot",
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans")
  ) +
  labs(
    title = "Global account ownership increased from 51 percent to 78 percent between 2011 and 2024",
    subtitle = "Adults with an account (%), 2011-2024",
    caption = "Source: Global Findex Database 2025"
  )

# Save the graph
ggsave(
  filename = file.path(folder_path, "figure_2_1_2.eps"),
  width = 8,
  height = 4,
  device = 'eps',
  dpi = 120
)
