c_list_income <- c("Low income", "Lower middle income", "Upper middle income", "High income")


# Define LMIC list
c_list_LMIC <- c("LMIC") |> sort()

# Prepare data
data_1 <- data %>%
  filter(group == "all", year %in% c(2014, 2017, 2021, 2024)) %>%
  filter(countrynewwb %in% c_list_LMIC, countrynewwb != "Belize") %>%
  select(countrynewwb, year, ts_account, ts_accfin_o, ts_accmob_o, ts_accany_b) %>%
  group_by(countrynewwb) %>%
  filter(any(year == 2024)) %>%
  ungroup() %>%
  filter(!is.na(ts_account)) %>%
  tidyr::gather(group, value, ts_accfin_o, ts_accmob_o, ts_accany_b) %>%
  mutate(
    total = ts_account * 100,
    value = value * 100
  ) %>%
  filter(!is.na(value), !is.na(total))

# Recode and re-factor country
data_1 <- data_1 %>%
  mutate(countrynewwb = ifelse(countrynewwb == "LMIC", "Low- and middle-income economies", countrynewwb))
c_list_LMIC <- c("Low- and middle-income economies")
data_1$countrynewwb <- factor(data_1$countrynewwb, levels = c_list_LMIC)

# Determine plot dimensions
length_unique_countries <- data_1 %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

if (length_unique_countries < 8) {
  width_num <- 8
  height_num <- 4
} else {
  width_num <- 8 + floor((length_unique_countries - 1) / 3) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 3)
}

# Determine y-axis maximum
max_val <- max(data_1$total, na.rm = TRUE) + 15
if (max_val > 92) {
  max_val <- 110
}

# Plot
ggplot(data_1) +
  geom_bar(
    aes(
      x = factor(year),
      y = value,
      fill = factor(group, levels = c("ts_accmob_o", "ts_accany_b", "ts_accfin_o"))
    ),
    stat = "identity",
    position = "stack",
    width = 0.75,
    color = "black",  # Black outline
    size = 0.25       # Outline width
  ) +
  scale_fill_manual(
    values = c("#5696D0", "#8066AB", "#D12891"),
    breaks = c("ts_accfin_o", "ts_accany_b", "ts_accmob_o"),
    labels = c(
      "Bank or similar financial institution account only",
      "Bank or similar financial institution account and mobile money account",
      "Mobile money account only"
    )
  ) +
  scale_y_continuous(
    limits = c(0, 100),
    breaks = seq(0, 100, by = 20)
  ) +
  facet_grid(. ~ factor(countrynewwb, levels = c_list_LMIC),
             scales = "free",
             space = "free",
             switch = "both",
             labeller = label_value) +
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0),
    strip.text.x = element_text(size = 16, family = "Nunito Sans", color = "black", angle = 0),
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    legend.box.margin = margin(0, 0, 20, 0),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(
      family = "Nunito Sans",
      color = "black",
      angle = 0,
      size = 16,
      hjust = 0.5,
      vjust = 0.5
    ),
    axis.text.y = element_text(
      family = "Nunito Sans",
      color = "black",
      size = 16
    ),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_line(color = "black"),
    legend.key.size = unit(4, "mm"),
    plot.subtitle = element_text(size = 16, color = "black", family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 16, color = "black", family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 16, color = "black", family = "Nunito Sans"),
    plot.caption = element_text(hjust = 0, size = 12, color = "black", family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 3, byrow = TRUE)) +
  labs(
    title = "Mobile money accounts contributed to the increase in account ownership in \nlow- and middle-income economies from 2014 to 2024",
    subtitle = "Adults with an account (%), 2014–2024",
    caption = "Source: Global Findex Database 2025"
  )


# Save
ggsave(
  filename = file.path(folder_path, "figure_2_1_4.png"),
  width = width_num-1,
  height = height_num+2,
  units = "in",
  device = "png",
  dpi = 120
)
