library(dplyr)
library(tidyr)
library(ggplot2)
library(showtext)
# 
# # Load Nunito Sans font
# font_add_google("Nunito Sans", "Nunito Sans")
# showtext_auto()

c_region <- c(#"High income", 
  "East Asia & Pacific (excluding high income)", "Europe & Central Asia (excluding high income)", 
  "Latin America & Caribbean (excluding high income)", "Middle East & North Africa (excluding high income)", 
  "South Asia (excluding high income)", "Sub-Saharan Africa (excluding high income)")

# Filter and format data
data_1 <- data %>% 
  filter(group == "all") %>%
  select(countrynewwb, year, group, ts_accmob_o, ts_accany_b, ts_accfin_o) %>% 
  filter(year == 2024, countrynewwb %in% c_region) %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))


# Reshape and compute totals
data_1 <- data_1 %>%
  pivot_longer(cols = c(ts_accmob_o, ts_accany_b, ts_accfin_o),
               names_to = "indicator",
               values_to = "value") %>%
  mutate(value = value * 100) %>%
  group_by(countrynewwb) %>%
  mutate(total = sum(value, na.rm = TRUE)) %>%
  ungroup()

# Create plot
ggplot(data_1) +
  geom_bar(
    aes(
      x = countrynewwb,
      y = value,
      fill = factor(indicator, levels = c("ts_accmob_o", "ts_accany_b", "ts_accfin_o"))
    ),
    stat = "identity",
    position = "stack",
    width = 0.75,
    color = "black",  # black outline
    size = 0.5       # outline width
  ) +
  scale_fill_manual(
    values = c("#D12891", "#8066AB", "#5696D0"),
    breaks = c("ts_accmob_o", "ts_accany_b", "ts_accfin_o"),
    labels = c(
      "Mobile money account only",
      "Bank or similar financial institution account and mobile money account",
      "Bank or similar financial institution account only"
    )
  ) +
  scale_y_continuous(
    limits = c(0, 100),
    breaks = seq(0, 100, by = 20)
  ) +
  facet_grid(. ~ countrynewwb,
             scales = "free",
             space = "free",
             switch = "both",
             labeller = labeller(countrynewwb = scales::wrap_format(16))) +
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0),
    strip.text.x = element_text(size = 16, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    legend.box.margin = margin(0, 0, 5, 0),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_blank(),
    axis.text.y = element_text(size = 16, color = "black", family = "Nunito Sans"),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_line(color = "black"),
    legend.key.size = unit(4, "mm"),
    plot.subtitle = element_text(size = 18, color = "black", family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 18, color = "black", family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 16, color = "black", family = "Nunito Sans"),
    plot.caption = element_text(hjust = 0, size = 12, color = "black", family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 3, byrow = TRUE, reverse = TRUE)) +
  labs(
    title = "Sub-Saharan Africa remains the region with the largest share of adults with only \nmobile money accounts",
    subtitle = "Adults with an account (%), 2024",
    caption = "Source: Global Findex Database 2025"
  )

# Save plot
ggsave(
  filename = file.path(folder_path, "figure_2_1_5.png"),
  width = width_num+0.5,
  height = height_num+2,
  units = "in",
  device = 'png',
  dpi = 120
)
