library(ggplot2)
library(dplyr)
library(tidyr)
library(forcats)
library(showtext)

c_region <- c(#"High income", 
  "East Asia & Pacific (excluding high income)", "Europe & Central Asia (excluding high income)", 
  "Latin America & Caribbean (excluding high income)", "Middle East & North Africa (excluding high income)", 
  "South Asia (excluding high income)", "Sub-Saharan Africa (excluding high income)")

Account_use_data <- data %>%
  filter(year == 2024, group == "all", countrynewwb %in% c_region) %>%
  select(countrynewwb, ts_account, ts_mobaccount, fin_dig_acc) %>%
  filter(!is.na(ts_account)) %>%
  mutate(
    second_stack = fin_dig_acc - ts_mobaccount,
    first_stack = ts_mobaccount,
    third_stack = ts_account - fin_dig_acc,
    total = ts_account
  ) %>%
  gather(group, value, first_stack, second_stack, third_stack) %>%
  filter(!is.na(group), !is.na(value)) %>%
  mutate(
    total = total * 100,
    value = value * 100
  ) %>%
  filter(!is.na(total)) %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))


length_unique_countries <- Account_use_data %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

if (length_unique_countries < 8) {
  width_num <- 8
  height_num <- 4
} else {
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

# Determine y-axis limit
max_val <- max(Account_use_data$total, na.rm = TRUE) + 15
if (max_val > 92) {
  max_val <- 120
}

# Create plot
ggplot(Account_use_data) +
  geom_bar(
    aes(
      y = fct_rev(countrynewwb),
      x = value,
      fill = factor(group, levels = c("third_stack", "second_stack", "first_stack"))
    ),
    stat = "identity",
    position = "stack",
    width = 0.6,
    color = "black",  # Black outline
    size = 0.75       # Outline thickness
  ) +
  scale_fill_manual(
    values = c("#C2C0C0", "#0F72BC", "#D12891"),
    labels = c(
      "third_stack" = "Have only a bank or similar financial institution account-\nbut do not make digital payments from the account",
      "first_stack" = "Use a mobile money account",
      "second_stack" = "Have only a bank or similar financial institution account-\nand make digital payments from the account using a card or phone"
    ),
    guide = guide_legend(reverse = TRUE)
  ) +
  scale_x_continuous(limits = c(0, 100), breaks = seq(0, 100, by = 20)) +
  theme(
    panel.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'left',
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 14),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16, hjust = 0),
    axis.ticks.y = element_line(color = "white"),
    axis.ticks.x = element_blank(),
    plot.subtitle = element_text(size = 16, family = "Nunito Sans", color = "black"),
    plot.title = element_text(hjust = 0, size = 18, family = "Nunito Sans", face = "bold", color = "black"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 16, family = "Nunito Sans", color = "black"),
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans", color = "black"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 3, byrow = FALSE, reverse = TRUE)) +
  labs(
    subtitle = "Adults with an account (%), 2024",
    title = "Most adults with an account in low-and middle-income economies have a digitally enabled account",
    caption = "Source: Global Findex Database 2025"
  )

# Save the figure
ggsave(
  filename = file.path(folder_path, "figure_2_1_6.png"),
  width = width_num+1.5,
  height = height_num+2.5,
  device = 'png',
  dpi = 120
)
