library(dplyr)
library(tidyr)
library(ggplot2)
library(scales)

# Prepare data
data_1 <- data %>%
  filter(group == "all") %>%
  filter(year %in% c(2014, 2017, 2021, 2024)) %>%
  filter(countrynewwb %in% c("AU_Central", "AU_East", "AU_West", "AU_Southern")) %>% 
  select(countrynewwb, year, ts_account, ts_accfin_o, ts_accmob_o, ts_accany_b) %>%
  group_by(countrynewwb) %>%
  filter(any(year == 2024)) %>% 
  ungroup() %>%
  filter(!is.na(ts_account)) %>%
  pivot_longer(cols = c(ts_accfin_o, ts_accmob_o, ts_accany_b),
               names_to = "group",
               values_to = "value") %>%
  mutate(
    total = ts_account * 100,
    value = value * 100,
    countrynewwb = recode(countrynewwb,
                          "AU_Central" = "Central Africa",
                          "AU_East" = "East Africa",
                          "AU_West" = "West Africa",
                          "AU_Southern" = "Southern Africa")
  ) %>%
  filter(!is.na(value)) %>%
  filter(!is.na(total))

# Create a list of region names in a nice order
c_list <- c("Central Africa", "East Africa", "Southern Africa", "West Africa")

# Calculate plot dimensions based on number of regions
length_unique_countries <- length(c_list)

if (length_unique_countries < 8) {
  width_num <- 8
  height_num <- 4
} else {
  width_num <- 8 + floor((length_unique_countries - 1) / 3) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 3)
}

cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

# Check max value for y-axis
max_val <- max(data_1$total, na.rm = TRUE) + 15
if (max_val > 92) {
  max_val <- 110
}

# Plot
p <- ggplot(data_1) +
  geom_bar(aes(
    x = factor(year),
    y = value,
    fill = factor(group, levels = c("ts_accmob_o", "ts_accany_b", "ts_accfin_o"))
  ),
  stat = "identity",
  position = "stack",
  width = 0.75,
  color = "black",   # Add black outline
  size = 0.5        # Set outline thickness
  ) +
  scale_fill_manual(
    values = c(
      "ts_accfin_o" = "#5696D0", 
      "ts_accany_b" = "#8066AB",
      "ts_accmob_o" = "#D12891"
    ),
    breaks = c("ts_accfin_o", "ts_accany_b", "ts_accmob_o"),
    labels = c(
      "Bank or similar financial institution account only",
      "Bank or similar financial institution account and mobile money account",
      "Mobile money account only"
    )
  ) +
  scale_y_continuous(
    limits = c(0, 100),
    breaks = seq(0, 80, by = 20)
  ) +
  facet_grid(. ~ factor(countrynewwb, levels = c_list),
             scales = "free",
             space = "free",
             switch = "both") +
  scale_x_discrete(labels = wrap_format(8)) +
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0),
    strip.text.x = element_text(size = 18, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = "center",
    legend.box.margin = margin(0, 0, 5, 0),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(
      family = "Nunito Sans",
      color = "black",
      angle = 0,
      size = 18,
      vjust = 0
    ),
    axis.text.y = element_text(
      family = "Nunito Sans",
      color = "black",
      size = 18
    ),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_line(color = "black"),
    legend.key.size = unit(4, "mm"),
    plot.subtitle = element_text(size = 20, color = "black", family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 20, color = "black", family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 18, color = "black", family = "Nunito Sans"),
    plot.caption = element_text(hjust = 0, size = 14, color = "black", family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 3, byrow = TRUE)) +
  labs(
    title = "Across all four sub-regions of Sub-Saharan, about 40 percent of adults have a mobile money \naccount in 2024",
    subtitle = "Adults with an account (%), 2014–24",
    caption = "Source: Global Findex Database 2025"
  )

# Display plot
print(p)

# Save the plot
ggsave(
  filename = file.path(folder_path, "figure_2_1_7.png"),
  plot = p,
  width = 10,
  height = 6,
  units = "in",
  device = "png",
  dpi = 120
)
