install.packages("patchwork")

library(dplyr)
library(ggplot2)
library(patchwork)

# Country list
c_list <- c(
  "world", "High income", "LMIC",
  "East Asia & Pacific (excluding high income)", "Europe & Central Asia (excluding high income)",
  "Latin America & Caribbean (excluding high income)", "Middle East & North Africa (excluding high income)",
  "South Asia (excluding high income)", "Sub-Saharan Africa (excluding high income)")

# Prepare data
data_combined <- data %>%
  filter(year == 2024) %>%
  filter(countrynewwb %in% c_list) %>%
  filter(!is.na(ts_account)) %>%
  select(countrynewwb, group2, ts_account) %>%
  filter(group2 %in% c(
    "women", "men",
    "poorest 40%", "richest 60%",
    "ages 15-24", "age 25+",
    "out of workforce", "employed for employer",
    "prim edu or less", "secondary edu or more",
    "urban", "rural"
  )) %>%
  mutate(
    group2 = case_when(
      group2 == "out of workforce" ~ "Out of workforce",
      group2 == "employed for employer" ~ "In workforce",
      group2 == "prim edu or less" ~ "Primary or less",
      group2 == "secondary edu or more" ~ "Secondary or more",
      group2 == "poorest 40%" ~ "Poorest 40% of households",
      group2 == "richest 60%" ~ "Wealthiest 60% of households",
      group2 == "ages 15-24" ~ "Ages 15-24",
      group2 == "age 25+" ~ "Age 25+",
      group2 == "women" ~ "Women",
      group2 == "men" ~ "Men",
      group2 == "urban" ~ "Urban",
      group2 == "rural" ~ "Rural",
      TRUE ~ group2
    ),
    group_type = case_when(
      group2 %in% c("Women", "Men") ~ "Gender",
      group2 %in% c("Poorest 40% of households", "Wealthiest 60% of households") ~ "Income",
      group2 %in% c("Ages 15-24", "Age 25+") ~ "Age",
      group2 %in% c("Out of workforce", "In workforce") ~ "Workforce",
      group2 %in% c("Primary or less", "Secondary or more") ~ "Education",
      group2 %in% c("Rural", "Urban") ~ "Urban-Rural",
      TRUE ~ NA_character_
    ),
    group2 = factor(group2, levels = c(
      "Women", "Men",
      "Poorest 40% of households", "Wealthiest 60% of households",
      "Ages 15-24", "Age 25+",
      "Primary or less", "Secondary or more",
      "Out of workforce", "In workforce",
      "Rural", "Urban"
    )),
    group_type = factor(group_type, levels = c("Gender", "Income", "Age", "Education", "Workforce", "Urban-Rural")),
    countrynewwb = factor(countrynewwb, levels = rev(c_list))
  ) %>%
  filter(!is.na(group_type)) %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "world" = "World",
                               "High income" = "High-income economies",
                               "LMIC" = "Low- and middle-income economies",
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"
  ))

# Custom color palette
custom_colors <- c(
  "Women" = "#5696D0", "Men" = "#8066AB",
  "Poorest 40% of households" = "#5696D0", "Wealthiest 60% of households" = "#8066AB",
  "Ages 15-24" = "#5696D0", "Age 25+" = "#8066AB",
  "Out of workforce" = "#5696D0", "In workforce" = "#8066AB",
  "Primary or less" = "#5696D0", "Secondary or more" = "#8066AB",
  "Rural" = "#5696D0", "Urban" = "#8066AB"
)

# Shared theme
base_theme <- theme_bw() +
  theme(
    panel.grid = element_blank(),
    panel.background = element_blank(),
    panel.border = element_blank(),
    axis.title = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", size = 18, color = "black"),
    axis.text.y = element_text(family = "Nunito Sans", size = 20, color = "black", hjust = 0),
    axis.ticks = element_blank(),
    legend.title = element_blank(),
    legend.text = element_text(size = 18, family = "Nunito Sans"),
    legend.key = element_blank(),                     # <- remove black box behind legend
    legend.key.height = unit(0.7, "cm"),
    legend.key.width = unit(0.6, "cm"),
    legend.position = "bottom",
    legend.direction = "vertical",
    legend.box = "vertical",
    plot.title = element_text(size = 20, family = "Nunito Sans", face = "bold", hjust = 0.5),
    plot.margin = margin(10, 10, 10, 10),
    plot.caption.position =  "plot",
    plot.caption = element_text(hjust = 0, size = 20, family = "Nunito Sans"),
    strip.background = element_blank()                # <- remove black box behind facet title
  )

# Function to create each panel
plot_facet <- function(group_name, show_yaxis = FALSE) {
  df <- data_combined %>% filter(group_type == group_name)
  
  p <- ggplot(df, aes(x = ts_account * 100, y = countrynewwb, color = group2)) +
    geom_line(aes(group = countrynewwb), color = "#C2C0C0", size = 0.7) +
    geom_point(size = 4) +
    geom_point(size = 4, shape = 1, color = "black") + 
    scale_color_manual(values = custom_colors) +
    scale_y_discrete(labels = wrap_format(18)) +
    labs(title = group_name) +
    base_theme +
    theme(
      axis.text.y = if (show_yaxis) element_text(family = "Nunito Sans", size = 20) else element_blank(),
      axis.ticks.y = element_blank()
    )
  return(p)
}

# Create all six panels
p_gender     <- plot_facet("Gender", show_yaxis = TRUE)
p_income     <- plot_facet("Income")
p_age        <- plot_facet("Age")
p_education  <- plot_facet("Education")
p_workforce  <- plot_facet("Workforce")
p_urbanrural <- plot_facet("Urban-Rural")

# Combine with patchwork
final_plot <- (p_gender | p_income | p_age | p_education | p_workforce | p_urbanrural) +
  plot_annotation(
    title = "Gender, income, age, education, workforce, and location gaps remain in every region around the world",
    subtitle = "Adults with an account (%), 2024",
    caption = "Source: Global Findex Database 2025\nNote: Employment status for adults in China is not available.",
    theme = theme(
      plot.title = element_text(family = "Nunito Sans", face = "bold", size = 22, hjust = 0, margin = margin(b = 5)),
      plot.subtitle = element_text(family = "Nunito Sans", size = 22, hjust = 0, margin = margin(b = 10)),
      plot.caption.position =  "plot",
      plot.caption = element_text(hjust = 0, size = 16, family = "Nunito Sans")
    )
  )

# Display the plot
print(final_plot)

# Save the plot
ggsave(
  filename = file.path(folder_path, "figure_2_1_8.png"),
  plot = final_plot,
  width = width_num+7.8,
  height = height_num+4.5,
  device = "png",
  dpi = 120
)
