library(dplyr)
library(ggplot2)
library(patchwork)

# Define survey years
survey_years <- c(2011, 2014, 2017, 2021, 2024)

# Prepare Gender data
data_gender <- data %>%
  filter(countrynewwb == "LMIC") %>%
  filter(group2 %in% c("women", "men")) %>%
  filter(!is.na(ts_account), year %in% survey_years) %>%
  mutate(
    group2 = recode(group2,
                    "women" = "Women",
                    "men" = "Men"),
    group2 = factor(group2, levels = c("Women", "Men")),
    year = factor(year, levels = survey_years)
  )

# Prepare Income data
data_income <- data %>%
  filter(countrynewwb == "LMIC") %>%
  filter(group2 %in% c("poorest 40%", "richest 60%")) %>%
  filter(!is.na(ts_account), year %in% survey_years) %>%
  mutate(
    group2 = recode(group2,
                    "poorest 40%" = "Poorest 40% of households",
                    "richest 60%" = "Wealthiest 60% of households"),
    group2 = factor(group2, levels = c("Poorest 40% of households", "Wealthiest 60% of households")),
    year = factor(year, levels = survey_years)
  )

# Gender Panel
plot_gender <- ggplot(data_gender, aes(x = year, y = ts_account * 100, color = group2, group = group2)) +
  geom_line(size = 1) +
  geom_point(aes(color = group2), size = 3) +
  geom_point(size = 3, shape = 1, color = "black") +
  scale_x_discrete() +
  scale_color_manual(values = c("Women" = "#5696D0", "Men" = "#8066AB")) +
  labs(
    title = "a. Gender",
    x = NULL,
    y = NULL,
    color = NULL
  ) +
  theme_bw() +
  theme(
    panel.grid = element_blank(),
    panel.background = element_blank(),
    panel.border = element_blank(),
    axis.text = element_text(size = 14, family = "Nunito Sans", color = "black"),
    plot.title = element_text(size = 16, family = "Nunito Sans", face = "bold", hjust = 0.5),
    legend.position = "bottom",
    legend.justification = "center",
    legend.text = element_text(size = 16, family = "Nunito Sans")
  )

# Income Panel (without y-axis numbers)
plot_income <- ggplot(data_income, aes(x = year, y = ts_account * 100, color = group2, group = group2)) +
  geom_line(size = 1) +
  geom_point(aes(color = group2), size = 3) +
  geom_point(size = 3, shape = 1, color = "black") +
  scale_x_discrete() +
  scale_color_manual(values = c(
    "Poorest 40% of households" = "#5696D0",
    "Wealthiest 60% of households" = "#8066AB"
  )) +
  labs(
    title = "b. Income",
    x = NULL,
    y = NULL,
    color = NULL
  ) +
  theme_bw() +
  theme(
    panel.grid = element_blank(),
    panel.background = element_blank(),
    panel.border = element_blank(),
    axis.text.x = element_text(size = 14, family = "Nunito Sans", color = "black"),
    axis.text.y = element_blank(),
    axis.ticks.y = element_blank(),
    plot.title = element_text(size = 16, family = "Nunito Sans", face = "bold", hjust = 0.5),
    legend.position = "bottom",
    legend.justification = "center",
    legend.text = element_text(size = 16, family = "Nunito Sans")
  )

# Combine the two panels
final_plot <- (plot_gender | plot_income) +
  plot_annotation(
    title = "Gender and income gaps in account ownership narrowed in low- and middle-income economies between 2011 and 2024",
    subtitle = "Adults with an account (%), 2011-2024",
    caption = "Source: Global Findex Database 2025",
    theme = theme(
      plot.caption.position =  "plot",
      plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans"),
      plot.title = element_text(size = 16, family = "Nunito Sans", face = "bold", hjust = 0),
      plot.subtitle = element_text(size = 16, family = "Nunito Sans", face = "plain", hjust = 0, margin = margin(b = 10))
    )
  )

# Display the plot
print(final_plot)

# Save the plot
ggsave(
  filename = file.path(folder_path, "figure_2_1_9.png"),
  plot = final_plot,
  width = 11,
  height = 5,
  units = "in",
  device = "png",
  dpi = 120
)
