library(dplyr)
library(tidyr)
library(ggplot2)
library(scales)
library(showtext)

# Set country list
c_region_LMIC <- c(#"High income", 
  "LMIC",
  "East Asia & Pacific (excluding high income)", "Europe & Central Asia (excluding high income)",
  "Latin America & Caribbean (excluding high income)", "Middle East & North Africa (excluding high income)",
  "South Asia (excluding high income)", "Sub-Saharan Africa (excluding high income)")

# Prepare the data
data_borrow_24 <- data %>%
  filter(group == "all") %>%
  filter(year == 2024) %>%
  filter(countrynewwb %in% c_region_LMIC) %>%
  select(countrynewwb, year, ts_anyborrowing, ts_borrfor_fi_cc_mm, ts_borr_semifor, ts_borrfam_MErank) %>%
  mutate(
    ts_borrow_other_ways = ts_anyborrowing - (ts_borrfor_fi_cc_mm + ts_borr_semifor + ts_borrfam_MErank)
  ) %>%
  pivot_longer(
    cols = c(ts_borrfor_fi_cc_mm, ts_borr_semifor, ts_borrfam_MErank, ts_borrow_other_ways),
    names_to = "group",
    values_to = "value"
  ) %>%
  filter(!is.na(value)) %>%
  mutate(value = value * 100) %>%
  group_by(countrynewwb) %>%
  mutate(total = sum(value, na.rm = TRUE)) %>%
  ungroup() %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "LMIC" = "Low- and middle-income economies",
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"
  ))

# Determine width and height
length_unique_countries <- data_borrow_24 %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

if (length_unique_countries < 8) {
  width_num <- 8
  height_num <- 4
} else {
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

# Max value for y-axis
max_val <- max(data_borrow_24$total, na.rm = TRUE) + 15
if (max_val > 100) {
  max_val <- 120
}

data_borrow_24 <- data_borrow_24 %>%
  mutate(
    countrynewwb = factor(
      countrynewwb,
      levels = c(
        "Low- and middle-income economies",
        setdiff(unique(countrynewwb), "Low- and middle-income economies"))))

# Create the plot
ggplot(data_borrow_24, aes(x = countrynewwb, y = value)) +
  geom_bar(
    aes(
      fill = factor(group, 
                    levels = c("ts_borrow_other_ways", "ts_borrfam_MErank", "ts_borr_semifor", "ts_borrfor_fi_cc_mm"))
    ),
    stat = "identity",
    position = "stack",
    width = 0.75,
    color = "black",   # black outline
    size = 0.75        # outline thickness
  ) +
  scale_fill_manual(
    values = c(
      "ts_borrfor_fi_cc_mm" = "#5696D0",        # Borrowed from bank/MM
      "ts_borr_semifor" = "#878787",            # Semi-formal borrowing
      "ts_borrfam_MErank" = "#C2C0C0",          # Borrowed from family/friends
      "ts_borrow_other_ways" = "#E6E6E6"        # Other ways
    ),
    breaks = c(
      "ts_borrfor_fi_cc_mm",
      "ts_borr_semifor",
      "ts_borrfam_MErank",
      "ts_borrow_other_ways"
    ),
    labels = c(
      "Borrowed formally",
      "Borrowed semiformally",
      "Borrowed from family or friends",
      "Borrowed using other ways"
    )
  ) +
  scale_x_discrete(labels = function(x) stringr::str_wrap(x, width = 16)) +
  scale_y_continuous(
    limits = c(0, max_val),
    breaks = seq(0, max_val, by = 20)
  ) +
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0),
    strip.text.x = element_text(size = 16, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = "center",
    legend.box.margin = margin(0, 0, 0, 0),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(
      family = "Nunito Sans",
      color = "black",
      angle = 0,
      size = 16,
      hjust = 0.5,
      vjust = 0.5
    ),
    axis.text.y = element_text(
      family = "Nunito Sans",
      color = "black",
      size = 14
    ),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_line(),
    plot.subtitle = element_text(size = 16, color = "black", family = "Nunito Sans"),
    plot.title = element_text(
      hjust = 0,
      size = 16,
      color = "black",
      family = "Nunito Sans",
      face = "bold"
    ),
    plot.title.position = "plot",
    legend.text = element_text(
      hjust = 0,
      size = 16,
      color = "black",
      family = "Nunito Sans"
    ),
    plot.caption = element_text(hjust = 0, size = 12, color = "black", family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 4, byrow = TRUE)) +
  labs(
    title = "About equal shares of borrowers cited formal credit and borrowing only from family and friends as sources of credit",
    subtitle = "Adults borrowing any money in the past year (%), 2024",
    caption = "Source: Global Findex Database 2025\nNote: People may borrow from multiple sources, but categories in the figure are constructed to be mutually exclusive. \"Borrowed formally\" includes all adults who borrowed any\nmoney from a bank or similar financial institution or through the use of a credit card or mobile money account. \"Borrowed semiformally\" includes all adults who borrowed any money\nsemiformally (from a savings club) but not formally. \"Borrowed from friends and family\" excludes all adults who borrowed formally or semiformally."
  )

# Save the figure
ggsave(
  filename = file.path(folder_path, "3.2.1.png"),
  width = 11,
  height = 8,
  units = "in",
  device = 'png',
  dpi = 120
)
