# library(dplyr)
# library(tidyr)
# library(ggplot2)
# library(scales)
# library(showtext)

# Define updated country list
c_list_agg <- c("Argentina", "Brazil", "China", "Turkiye", "Ukraine")

# Legend labels (with Turkey fix)
legend_labels <- c(
  "Argentina" = "Argentina",
  "Brazil" = "Brazil",
  "China" = "China",
  "Turkiye" = "Trkiye",
  "Ukraine" = "Ukraine"
)

# Prepare the data
data_formal_borrowing <- data %>%
  filter(group == "all") %>%
  filter(year == 2024) %>%
  filter(countrynewwb %in% c_list_agg) %>%
  select(countrynewwb, year, ts_borrfor_fi_cc_mm, ts_borrfor_cc_MErank) %>%
  mutate(
    borrowed_formal_but_not_cc = ts_borrfor_fi_cc_mm - ts_borrfor_cc_MErank
  ) %>%
  pivot_longer(
    cols = c(ts_borrfor_cc_MErank, borrowed_formal_but_not_cc),
    names_to = "group",
    values_to = "value"
  ) %>%
  filter(!is.na(value)) %>%
  mutate(value = value * 100) %>%
  group_by(countrynewwb) %>%
  mutate(total = sum(value, na.rm = TRUE)) %>%
  ungroup()

# Determine width and height
length_unique_countries <- data_formal_borrowing %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

if (length_unique_countries < 8) {
  width_num <- 8
  height_num <- 4
} else {
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# Max value for y-axis
max_val <- max(data_formal_borrowing$total, na.rm = TRUE) + 15
if (max_val > 100) {
  max_val <- 120
}

# Plot with horizontal bars
p <- ggplot(data_formal_borrowing, aes(y = factor(countrynewwb, levels = rev(c_list_agg)), x = value)) +
  geom_bar(
    aes(
      fill = factor(group, 
                    levels = c("ts_borrfor_cc_MErank", "borrowed_formal_but_not_cc"))
    ),
    stat = "identity",
    position = "stack",
    width = 0.75,
    color = "black",
    size = 0.75
  ) +
  scale_fill_manual(
    values = c(
      "ts_borrfor_cc_MErank" = "#5696D0",            # Used credit card
      "borrowed_formal_but_not_cc" = "#0F72BC"        # Borrowed formally but not credit card
    ),
    breaks = c(
      "borrowed_formal_but_not_cc",
      "ts_borrfor_cc_MErank"
    ),
    labels = c(
      "Borrowed from a bank or similar financial institution or using a mobile money account",
      "Used a credit card but did not borrow from a bank or similar financial institution or using a mobile money account"
    )
  ) +
  scale_x_continuous(
    limits = c(0, max_val),
    breaks = seq(0, max_val, by = 20)
  ) +
  scale_y_discrete(labels = function(x) legend_labels[x]) +
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0),
    strip.text.x = element_text(size = 16, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = "center",
    legend.box.margin = margin(0, 0, 20, 0),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.y = element_text(
      family = "Nunito Sans",
      color = "black",
      size = 12,
      hjust = 0.5,
      vjust = 1,
      angle = 0
    ),
    axis.text.x = element_text(
      family = "Nunito Sans",
      color = "black",
      size = 14
    ),
    axis.ticks.y = element_blank(),
    axis.ticks.x = element_blank(),
    plot.subtitle = element_text(size = 16, color = "black", family = "Nunito Sans"),
    plot.title = element_text(
      hjust = 0,
      size = 16,
      color = "black",
      family = "Nunito Sans",
      face = "bold"
    ),
    plot.title.position = "plot",
    legend.text = element_text(
      hjust = 0,
      size = 12,
      color = "black",
      family = "Nunito Sans"
    ),
    plot.caption = element_text(hjust = 0, size = 12, color = "black", family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 2, byrow = TRUE)) +
  labs(
    title = "Credit card use dominated formal borrowing in some low- and middle-income economies",
    subtitle = "Adults borrowing formally in the past year (%), 2024",
    caption = "Source: Global Findex Database 2025")

# Print plot
print(p)

# Save plot
ggsave(
  filename = file.path(folder_path, "3.2.4.png"),
  plot = p,
  width = 10,
  height = 5,
  units = "in",
  device = 'png',
  dpi = 120
)
