# library(dplyr)
# library(tidyr)
# library(ggplot2)
# library(scales)
# library(showtext)

# Define region list
c_list_agg <- c("Argentina", "Brazil", "China", "Turkiye", "Ukraine")

# Legend labels (with Turkey fix)
legend_labels <- c(
  "Argentina" = "Argentina",
  "Brazil" = "Brazil",
  "China" = "China",
  "Turkiye" = "Trkiye",
  "Ukraine" = "Ukraine"
)

# Prepare the data
data_cc_use <- data %>%
  filter(group == "all", year == 2024, countrynewwb %in% c_list_agg) %>%
  select(countrynewwb, year, fin10_all, fin_cc_nouse, fin_cc_paid_balance, fin_cc_nopaid_balance) %>%
  mutate(
    fin10_all = fin10_all * 100,
    unused_card = fin_cc_nouse * 100,
    used_paid_full = fin_cc_paid_balance * 100,
    used_not_full = fin_cc_nopaid_balance * 100
  ) %>%
  pivot_longer(
    cols = c(unused_card, used_not_full, used_paid_full),
    names_to = "group",
    values_to = "value"
  ) %>%
  filter(!is.na(value)) %>%
  group_by(countrynewwb) %>%
  mutate(total = sum(value, na.rm = TRUE)) %>%
  ungroup()

# Plot with horizontal bars
p <- ggplot(data_cc_use, aes(y = factor(countrynewwb, levels = rev(c_list_agg)), x = value)) +
  geom_bar(
    aes(fill = factor(group, levels = c("unused_card", "used_not_full", "used_paid_full"))),
    stat = "identity",
    position = "stack",
    width = 0.75,
    color = "black",
    size = 0.75
  ) +
  scale_fill_manual(
    values = c(
      "used_paid_full" = "#5696D0",  # Medium blue
      "used_not_full" = "#B2D6F7",   # Light blue
      "unused_card" = "#C2C0C0"      # Grey
    ),
    breaks = c("used_paid_full", "used_not_full", "unused_card"),
    labels = c(
      "Used credit card and paid off balance in full",
      "Used credit card and did not pay balance in full",
      "Owns credit card and did not use it in the past 12 months"
    )
  ) +
  scale_x_continuous(
    limits = c(0, 60),
    breaks = seq(0, 60, by = 20)
  ) +
  scale_y_discrete(labels = function(x) legend_labels[x]) +
  theme(
    strip.placement = "outside",
    strip.text.x = element_text(size = 16, family = "Nunito Sans", colour = "black"),
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = "center",
    legend.box.margin = margin(0, 0, 20, 0),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 12),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 14),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_blank(),
    plot.subtitle = element_text(size = 16, color = "black", family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 16, color = "black", family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 12, color = "black", family = "Nunito Sans"),
    plot.caption = element_text(hjust = 0, size = 12, color = "black", family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 3, byrow = TRUE)) +
  labs(
    title = "Most credit card users reported paying off their balance in full in low- and middle-income\n economies with high credit card use",
    subtitle = "Adults with a credit card (%), 2024",
    caption = "Source: Global Findex Database 2025"
  )

# Print plot
print(p)

# Save plot
ggsave(
  filename = file.path(folder_path, "3.2.5.png"),
  plot = p,
  width = 10,
  height = 5,
  units = "in",
  device = 'png',
  dpi = 120
)
