c_list_agg <- c("Ghana", "Kenya", "Uganda") 

library(scales)
library(dplyr)
library(tidyr)
library(ggplot2)

legend_labels <- c(
  "Ghana" = "Ghana", 
  "Kenya" = "Kenya", 
  "Uganda" = "Uganda"
)

# Prepare the data
data_cut <- data %>%
  filter(year %in% c(2021, 2024)) %>%
  filter(group == "all") %>%
  filter(countrynewwb %in% c_list_agg) %>%
  mutate(
    ts_borr_other = ts_anyborrowing - ts_borrfor_fi_cc - ts_borrfor_mm_MErank - ts_borr_semifor_MErank - ts_borrfam_MErank,
    borr_fi_cc_only = ts_borrfor_fi_cc_MErank * 100,
    borr_mm_only = ts_borrfor_mm_MErank * 100,
    borr_both = (ts_borrfor_fi_cc + ts_borrfor_mm - ts_borrfor_fi_cc_mm) * 100,
    borr_semiformal = ts_borr_semifor_MErank * 100,
    borr_other = ts_borr_other * 100,
    ts_borrfam_MErank = ts_borrfam_MErank * 100
  )

plot_borr <- data_cut %>%
  select(countrynewwb, year, borr_fi_cc_only, borr_both, borr_mm_only, borr_semiformal, borr_other, ts_borrfam_MErank, ts_anyborrowing) %>%
  pivot_longer(cols = c(borr_fi_cc_only, borr_both, borr_mm_only, borr_semiformal, ts_borrfam_MErank, borr_other), names_to = "group", values_to = "value") %>%
  mutate(
    total = ts_anyborrowing * 100,
    country_label = recode(countrynewwb, !!!legend_labels)
  ) %>%
  filter(!is.na(value))

# Create plot
p <- ggplot(plot_borr) +
  geom_bar(
    aes(
      x = factor(year),
      y = value,
      fill = factor(group, levels = c(
        "borr_other", "ts_borrfam_MErank", "borr_semiformal", "borr_mm_only", "borr_both", "borr_fi_cc_only"
      ))
    ),
    stat = "identity",
    position = "stack",
    width = 0.75,
    color = "black",
    size = 0.75
  ) +
  scale_fill_manual(
    values = c(
      "borr_fi_cc_only" = "#0F72BC",
      "borr_both" = "#8066AB",
      "borr_mm_only" = "#D12891",
      "borr_semiformal" = "#B2D6F7",
      "ts_borrfam_MErank" = "#C2C0C0",
      "borr_other" = "#E6E6E6"
    ),
    breaks = c("borr_fi_cc_only", "borr_both", "borr_mm_only", "borr_semiformal", "ts_borrfam_MErank", "borr_other"),
    labels = c(
      "Borrowed from a bank or similar financial institution or using a credit card",
      "Borrowed from a bank or similar financial institution or using a credit card and using a mobile money account",
      "Borrowed using a mobile money account only",
      "Borrowed semiformally",
      "Borrowed from family or friends",
      "Borrowed using other methods"
    )
  ) +
  scale_y_continuous(
    limits = c(0, 100),
    breaks = seq(0, 110, by = 20)
  ) +
  facet_grid(. ~ country_label,
             scales = "free_x",
             space = "free_x",
             switch = "both",
             labeller = label_wrap_gen(width = 18)) +
  theme(
    strip.placement = "outside",
    strip.text.x = element_text(size = 18, family = "Nunito Sans", colour = "black"),
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = "center",
    legend.box.margin = margin(0, 0, 20, 0),
    axis.text.x = element_text(size = 16, family = "Nunito Sans", color = "black", margin = margin(t = 5)),
    axis.text.y = element_text(size = 16, family = "Nunito Sans", color = "black"),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_line(color = "black"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    plot.subtitle = element_text(size = 22, color = "black", family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 24, color = "black", family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 18, color = "black", family = "Nunito Sans"),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0, size = 16, color = "black", family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(ncol = 1)) +
  labs(
    subtitle = "Adults borrowing any money in the past years (%), 2021-2024",
    title = "In Ghana, Kenya, and Uganda more than 20 percent of adults borrowed from their mobile money provider in 2024",
    caption = "Source: Global Findex Database 2025\n\nNote: People may borrow from multiple sources, but categories in the figure are constructed to be mutually exclusive. \"Borrowed formally\" includes all adults who borrowed any money from a bank or\nsimilar financial institution or through the use of a credit card or mobile money account. \"Borrowed semiformally\" includes all adults who borrowed any money semiformally (from a savings club) but not\nformally.\"Borrowed from friends and family\" excludes all adults who borrowed formally or semiformally."
  )

# Show plot
p

# Save plot
ggsave(
  filename = file.path(folder_path, "3.2.6.png"),
  plot = p,
  width = 20,
  height = 10,
  units = "in",
  device = 'png',
  dpi = 120
)
