
data_EAP <- data %>%
  filter(countrynewwb %in% c_region) %>%
  #filter(regionwb24_hi %in% "Sub-Saharan Africa (excluding high income)") %>%
  filter(year == 2024) %>%
  filter(group2 %in% c("employed for employer", "self-employed")) %>%
  select(countrynewwb, year, group2, con9_all_smart, con1_all, con9_all_basic)

# Reshape the data and create the indicator column
data_long <- data_EAP %>%
  pivot_longer(cols = c(con9_all_smart, con1_all, con9_all_basic),  # Specify columns to reshape
               names_to = "indicator",  # Name of the new column containing the indicator names
               values_to = "value")  # Name of the new column containing the values

# Rename the indicators to more readable names
data_long <- data_long %>%
  mutate(indicator = recode(indicator,  
                            con1_all = "Any phone",
                            con9_all_basic = "Basic phone",
                            con9_all_smart = "Smartphone")) %>%
  mutate(value = value * 100)

# Check the number of unique countries in countrynewwb
length_unique_countries <- data_long %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

if (length_unique_countries < 8) {
  width_num <-8
  height_num <-4 # default setting as 8 countries
} else{
  # Every two country added ,width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

data_long$countrynewwb <- forcats::fct_rev(factor(data_long$countrynewwb))

data_long$indicator <- factor(data_long$indicator, 
                              levels = c("Any phone", "Basic phone", "Smartphone"))

data_long <- data_long %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))

order_levels <- c("East Asia and Pacific", 
                  "Europe and Central Asia", 
                  "Latin America and the Caribbean", 
                  "Middle East and North Africa", 
                  "South Asia", 
                  "Sub-Saharan Africa")

# Reorder the 'countrynewwb' factor based on the specified order
data_long$countrynewwb <- factor(data_long$countrynewwb, levels = rev(order_levels))

# Create the barbell plot
ggplot(data_long, aes(x = value, y = countrynewwb, color = group2)) +
  # Draw lines (geom_segment) connecting points for men and women across indicators
  geom_path(color = "#c2C0C0", size = 0.7) +
  # Add points at the ends of the lines (barbell)
  geom_point(aes(color = group2), size = 4) +
  geom_point(size = 4, shape = 1, color = "black") +
  scale_color_manual(
    values = c("employed for employer" = "#5696D0", "self-employed" = "#8066AC"),
    labels = c("employed for employer" = "Wage-employed", "self-employed" = "Self-employed")
  ) +
  facet_grid(. ~ indicator, scales = "fixed", space = "free_x") +
  scale_y_discrete(labels = wrap_format(18)) +
  labs(
    caption = "Source: Global Findex Database 2025 \nNote: The data included in the regional and low- and middle-income averages exclude several large economies that were surveyed by phone, including China and Russia. \nSee the Methodology section in Annex X for a detailed list of all included countries and survey methods.",
    title = "Differences in mobile phone ownership by employment status and type of phone",
    subtitle = "Adults with a phone (%), 2024",
    x = NULL,
    y = NULL,
    color = NULL  # No global legend title
  ) +
  theme_bw() +  # Use white background
  theme(
    panel.grid = element_blank(),
    panel.background = element_blank(),
    axis.title.y = element_blank(),
    axis.title.x = element_blank(),
    plot.title.position = "plot",
    axis.text.x = element_text(family = "Nunito Sans", size = 20, color = "black"),
    axis.text.y = element_text(family = "Nunito Sans", size = 20, color = "black", hjust = 0),
    axis.ticks = element_blank(),
    plot.title = element_text(size = 22, family = "Nunito Sans", face = "bold", hjust = 0),
    plot.subtitle = element_text(size = 20, family = "Nunito Sans", hjust = 0, margin = margin(b = 10)),
    legend.title = element_blank(),
    legend.text = element_text(size = 20, family = "Nunito Sans"),
    legend.position = "bottom",
    legend.spacing.x = unit(0.25, "cm"),
    strip.text = element_text(size = 20, family = "Nunito Sans", face = "bold", color = "black"),
    strip.background = element_blank(),
    panel.spacing = unit(1, "lines"),
    plot.margin = margin(t = 10, r = 20, b = 10, l = 10),
    panel.border = element_blank(),
    plot.caption = element_text(hjust = 0,
                                size = 15,
                                family = "Nunito Sans"),
    plot.caption.position = "plot") +
  # Add vertical lines at the facet boundaries
  geom_vline(
    xintercept = c(100),  # Vertical lines at the edge of the graph
    color = "#C2C0C0",
    size = 0.5,  # Consistent thickness
    linetype = "solid"
  )

# Save the plot with a white background
ggsave(
  filename = file.path(folder_path, sprintf("phonetype_employment.png")),
  width = width_num+5.5,
  height = height_num+4,
  units = "in",
  device = 'png',
  dpi = 120)
