
# Load necessary libraries
library(ggplot2)
library(dplyr)
library(tidyr)
library(scales)
library(stringr)
library(forcats)

nophone_reason_data <- data %>%
  filter(year == 2024) %>%
  filter(group %in% c("all", "gender", "income")) %>%
  # filter(aggregate_level == "African_Union") %>%
  # filter(!countrynewwb == "AU_North") %>%
  filter(countrynewwb %in% c("South Asia (excluding high income)")) %>%
  select(group, group2, con2a_np_mon, con2b_np_exp, con2c_np_cov, con2d_np_typ, con2e_np_cov, 
         con2f_np_sec, con2g_np_els, con1_all, con3_np_mon, con3_np_exp, con3_np_cov, 
         con3_np_typ, con3_np_fam, con3_np_sec, con3_np_els)%>%
  filter(!is.na(con2a_np_mon)) %>%
  group_by(group2) %>%
  ungroup() 


indicator_mapping <- data.frame(
  indicator = c("con3_np_mon", "con3_np_exp", "con3_np_cov", "con3_np_typ",
                "con3_np_fam", "con3_np_sec", "con3_np_els",
                "con2a_np_mon", "con2b_np_exp", "con2c_np_cov", "con2d_np_typ", "con2e_np_cov", "con2f_np_sec", "con2g_np_els"),
  reasons_any_label = c(
    "Do not have enough money for a device",
    "Buying mobile minutes is too expensive",
    "No reliable coverage",
    "Difficulty reading or typing",
    "Family or community disapproval",
    "Personal safety or security concerns",
    "Use someone else's phone",
    "Do not have enough money for a device",
    "Buying mobile minutes is too expensive",
    "No reliable coverage",
    "Difficulty reading or typing",
    "Family or community disapproval",
    "Personal safety or security concerns",
    "Use someone else's phone"
  )
)

nophone_reason_data <- nophone_reason_data %>%
  pivot_longer(cols = starts_with("con") & !starts_with("con1_all"),
               names_to = "indicator",
               values_to = "value") %>%
  filter(!is.na(value))

nophone_reason_data <- nophone_reason_data %>%
  left_join(indicator_mapping, by = "indicator")


main_reasons <- c("con3_np_mon", "con3_np_exp", "con3_np_cov", "con3_np_typ",
                  "con3_np_fam", "con3_np_sec", "con3_np_els")

any_reasons <- c("con2a_np_mon", "con2b_np_exp", "con2c_np_cov", "con2d_np_typ", "con2e_np_cov", "con2f_np_sec", "con2g_np_els")

nophone_reason_data <- nophone_reason_data %>%
  mutate(
    reason_type = case_when(
      indicator %in% main_reasons ~ "Main reason",
      indicator %in% any_reasons ~ "Any reason",
      TRUE ~ "Other"  # You can adjust this part if you have more categories
    )
  )

# Convert the 'Value' column to percentages (multiply by 100)
nophone_reason_data <- nophone_reason_data %>%
  mutate(value = value * 100)

# Find the min and max values of 'Value' for proper scaling
min_value <- min(nophone_reason_data$value, na.rm = TRUE)
max_value <- max(nophone_reason_data$value, na.rm = TRUE)

# nophone_reason_data <- nophone_reason_data %>%
#   mutate(countrynewwb = recode(countrynewwb,
#                                "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
#                                "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
#                                "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
#                                "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
#                                "South Asia (excluding high income)" = "South Asia",
#                                "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))

nophone_reason_data <- nophone_reason_data %>%
  mutate(group2 = recode(group2, 
                         "all" = "All",
                         "women" = "Women",
                         "men" = "Men",
                         "poorest 40%" = "Lowest 40%",
                         "richest 60%" = "Wealthiest 60%",
                         "rural" = "Rural",
                         "urban" = "Urban"))

group_order <- c("All", "Women", "Men", "Lowest 40%", "Wealthiest 60%", "Rural", "Urban")
nophone_reason_data <- nophone_reason_data %>%
  mutate(group2 = factor(group2, levels = group_order))

# Add the phone ownership percentage (con1_all) next to the country name
nophone_reason_data <- nophone_reason_data %>%
  group_by(group2) %>%
  mutate(
    country_label = paste0(group2, " (", ifelse(!is.na(con1_all), paste0(round((1 - con1_all) * 100), "%"), "None"), ")")
  ) %>%
  ungroup() %>%
  filter(!is.na(con1_all)) %>%
  mutate(country_label = factor(country_label, levels = unique(country_label[order(group2)])))

# Define the correct order for reasons_any_label
reason_order <- c(
  "Do not have enough money for a device",
  "Buying mobile minutes is too expensive",
  "Difficulty reading or typing",
  "Use someone else's phone",
  "Personal safety or security concerns",
  "No reliable coverage",
  "Family or community disapproval"
)

nophone_reason_data <- nophone_reason_data %>%
  mutate(reasons_any_label = factor(reasons_any_label, levels = reason_order))

heatmap_plot <- ggplot(nophone_reason_data, aes(x = reason_type,
                                                y = forcats::fct_rev(country_label),  
                                                fill = value)) +
  geom_tile(color = "black") +  # Tile borders
  scale_fill_gradient2(high = "#D3172A", mid = "#E9867D", low = "#C2C0C0", 
                       midpoint = (max_value + min_value) / 2, 
                       limits = c(min_value, 80), 
                       name = "Value (%)",
                       labels = label_percent(scale = 1)) +  # Format the legend as percentages
  geom_text(aes(label = paste0(round(value), "%")), color = "black", size = 8) +  # Add percentage labels
  
  # Keep the main and any reasons together and reorder based on reason_type
  facet_wrap(~ reasons_any_label, scales = "free_x", nrow = 1, 
             labeller = labeller(reasons_any_label = function(x) str_wrap(x, width = 15))) +
  
  # Modify reason_type labels directly here instead of using str_to_title
  scale_x_discrete(position = "top") +
  
  labs(
    caption = "Source: Global Findex Database 2025\nNote: Numbers in parentheses represent the share of adults who do not own a phone.",
    title = "A lack of money and the cost of a phone present significant barriers to connectivity",
    subtitle = "Adults who do not own a phone (%), 2024"
  ) +
  
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0, hjust = 0, size = 22),  # Reduce size of y facet labels
    strip.text.x = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0),  # Reduce size of x facet labels
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.text = element_text(hjust = 0, size = 22, family = "Nunito Sans"),  # Adjust legend text size here
    legend.justification = 'center',
    legend.key.size = unit(4, "mm"),
    legend.key.width = unit(1.5, "cm"),  # Increase width of legend key
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 22, hjust = 0),  # Adjust y-axis text size
    axis.ticks.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 18, face = "bold"),  # Adjust x-axis text size
    axis.ticks.x = element_blank(),
    plot.subtitle = element_text(size = 22, family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 22, family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    plot.caption = element_text(hjust = 0, size = 18, family = "Nunito Sans"),
    plot.caption.position = "plot"
  )

# Display the plot
print(heatmap_plot)

# Export the image
ggsave(
  filename = file.path(folder_path, ("noPhone_any_main_reasons_SA.png")),
  width = 22, 
  height = 7, 
  units = "in", 
  device = 'png', 
  dpi = 120
)


# do again for SSA

nophone_reason_data <- data %>%
  filter(year == 2024) %>%
  filter(group %in% c("all", "gender", "income")) %>%
  # filter(aggregate_level == "African_Union") %>%
  # filter(!countrynewwb == "AU_North") %>%
  filter(countrynewwb %in% c("Sub-Saharan Africa (excluding high income)")) %>%
  select(group, group2, con2a_np_mon, con2b_np_exp, con2c_np_cov, con2d_np_typ, con2e_np_cov, 
         con2f_np_sec, con2g_np_els, con1_all, con3_np_mon, con3_np_exp, con3_np_cov, 
         con3_np_typ, con3_np_fam, con3_np_sec, con3_np_els)%>%
  filter(!is.na(con2a_np_mon)) %>%
  group_by(group2) %>%
  ungroup() 


indicator_mapping <- data.frame(
  indicator = c("con3_np_mon", "con3_np_exp", "con3_np_cov", "con3_np_typ",
                "con3_np_fam", "con3_np_sec", "con3_np_els",
                "con2a_np_mon", "con2b_np_exp", "con2c_np_cov", "con2d_np_typ", "con2e_np_cov", "con2f_np_sec", "con2g_np_els"),
  reasons_any_label = c(
    "Do not have enough money for a device",
    "Buying mobile minutes is too expensive",
    "No reliable coverage",
    "Difficulty reading or typing",
    "Family or community disapproval",
    "Personal safety or security concerns",
    "Use someone else's phone",
    "Do not have enough money for a device",
    "Buying mobile minutes is too expensive",
    "No reliable coverage",
    "Difficulty reading or typing",
    "Family or community disapproval",
    "Personal safety or security concerns",
    "Use someone else's phone"
  )
)

nophone_reason_data <- nophone_reason_data %>%
  pivot_longer(cols = starts_with("con") & !starts_with("con1_all"),
               names_to = "indicator",
               values_to = "value") %>%
  filter(!is.na(value))

nophone_reason_data <- nophone_reason_data %>%
  left_join(indicator_mapping, by = "indicator")


main_reasons <- c("con3_np_mon", "con3_np_exp", "con3_np_cov", "con3_np_typ",
                  "con3_np_fam", "con3_np_sec", "con3_np_els")

any_reasons <- c("con2a_np_mon", "con2b_np_exp", "con2c_np_cov", "con2d_np_typ", "con2e_np_cov", "con2f_np_sec", "con2g_np_els")

nophone_reason_data <- nophone_reason_data %>%
  mutate(
    reason_type = case_when(
      indicator %in% main_reasons ~ "Main reason",
      indicator %in% any_reasons ~ "Any reason",
      TRUE ~ "Other"  # You can adjust this part if you have more categories
    )
  )

# Convert the 'Value' column to percentages (multiply by 100)
nophone_reason_data <- nophone_reason_data %>%
  mutate(value = value * 100)

# Find the min and max values of 'Value' for proper scaling
min_value <- min(nophone_reason_data$value, na.rm = TRUE)
max_value <- max(nophone_reason_data$value, na.rm = TRUE)

# nophone_reason_data <- nophone_reason_data %>%
#   mutate(countrynewwb = recode(countrynewwb,
#                                "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
#                                "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
#                                "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
#                                "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
#                                "South Asia (excluding high income)" = "South Asia",
#                                "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))

nophone_reason_data <- nophone_reason_data %>%
  mutate(group2 = recode(group2, 
                         "all" = "All",
                         "women" = "Women",
                         "men" = "Men",
                         "poorest 40%" = "Lowest 40%",
                         "richest 60%" = "Wealthiest 60%",
                         "rural" = "Rural",
                         "urban" = "Urban"))

group_order <- c("All", "Women", "Men", "Lowest 40%", "Wealthiest 60%", "Rural", "Urban")
nophone_reason_data <- nophone_reason_data %>%
  mutate(group2 = factor(group2, levels = group_order))

# Add the phone ownership percentage (con1_all) next to the country name
nophone_reason_data <- nophone_reason_data %>%
  group_by(group2) %>%
  mutate(
    country_label = paste0(group2, " (", ifelse(!is.na(con1_all), paste0(round((1 - con1_all) * 100), "%"), "None"), ")")
  ) %>%
  ungroup() %>%
  filter(!is.na(con1_all)) %>%
  mutate(country_label = factor(country_label, levels = unique(country_label[order(group2)])))

# Define the correct order for reasons_any_label
reason_order <- c(
  "Do not have enough money for a device",
  "Buying mobile minutes is too expensive",
  "Difficulty reading or typing",
  "Use someone else's phone",
  "Personal safety or security concerns",
  "No reliable coverage",
  "Family or community disapproval"
)

nophone_reason_data <- nophone_reason_data %>%
  mutate(reasons_any_label = factor(reasons_any_label, levels = reason_order))

heatmap_plot <- ggplot(nophone_reason_data, aes(x = reason_type,
                                                y = forcats::fct_rev(country_label),  
                                                fill = value)) +
  geom_tile(color = "black") +  # Tile borders
  scale_fill_gradient2(high = "#D3172A", mid = "#E9867D", low = "#C2C0C0", 
                       midpoint = (max_value + min_value) / 2, 
                       limits = c(min_value, 82), 
                       name = "Value (%)",
                       labels = label_percent(scale = 1)) +  # Format the legend as percentages
  geom_text(aes(label = paste0(round(value), "%")), color = "black", size = 8) +  # Add percentage labels
  
  # Keep the main and any reasons together and reorder based on reason_type
  facet_wrap(~ reasons_any_label, scales = "free_x", nrow = 1, 
             labeller = labeller(reasons_any_label = function(x) str_wrap(x, width = 15))) +
  
  # Modify reason_type labels directly here instead of using str_to_title
  scale_x_discrete(position = "top") +
  
  labs(
    caption = "Source: Global Findex Database 2025\nNote: Numbers in parentheses represent the share of adults who do not own a phone.",
    title = "A lack of money and the cost of a phone present significant barriers to connectivity",
    subtitle = "Adults who do not own a phone (%), 2024"
  ) +
  
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0, hjust = 0, size = 22),  # Reduce size of y facet labels
    strip.text.x = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0),  # Reduce size of x facet labels
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.text = element_text(hjust = 0, size = 22, family = "Nunito Sans"),  # Adjust legend text size here
    legend.justification = 'center',
    legend.key.size = unit(4, "mm"),
    legend.key.width = unit(1.5, "cm"),  # Increase width of legend key
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 22, hjust = 0),  # Adjust y-axis text size
    axis.ticks.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 18, face = "bold"),  # Adjust x-axis text size
    axis.ticks.x = element_blank(),
    plot.subtitle = element_text(size = 22, family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 22, family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    plot.caption = element_text(hjust = 0, size = 18, family = "Nunito Sans"),
    plot.caption.position = "plot"
  )

# Display the plot
print(heatmap_plot)

# Export the image
ggsave(
  filename = file.path(folder_path, ("noPhone_any_main_reasons_SSA.png")),
  width = 22, 
  height = 7, 
  units = "in", 
  device = 'png', 
  dpi = 120
)





