
internet_use <- data %>%
  filter(year == 2024) %>%
  #filter(aggregate_level == "African_Union") %>%
  filter(countrynewwb %in% c_region) %>%
  select(countrynewwb, group2, con_internet3) %>%
  filter(group2 %in% c("women", "men", "poorest 40%", "richest 60%")) %>%
  mutate(
    group_type = case_when(
      group2 %in% c("women", "men") ~ "By gender",
      group2 %in% c("poorest 40%", "richest 60%") ~ "By income",
      TRUE ~ NA_character_  # Exclude unmatched rows
    ),
    int_value = con_internet3 * 100,  # Use con1_all for Any phone
    group2 = factor(group2, levels = c("women", "men", "poorest 40%", "richest 60%")),
    countrynewwb = factor(countrynewwb, levels = sort(unique(countrynewwb), decreasing = TRUE))
  ) %>%
  filter(!is.na(group_type))  # Remove rows with missing group_type

# Check the number of unique countries in countrynewwb
length_unique_countries <- internet_use %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)


if (length_unique_countries < 8) {
  width_num <-8
  height_num <-4 # default setting as 8 countries
} else{
  # Every two country added ,width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")


internet_use$group_type <- factor(internet_use$group_type, 
                                     levels = c("By gender", "By income"))

internet_use <- internet_use %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))

order_levels <- c("High income", 
                  "East Asia and Pacific", 
                  "Europe and Central Asia", 
                  "Latin America and the Caribbean", 
                  "Middle East and North Africa", 
                  "South Asia", 
                  "Sub-Saharan Africa")

# Reorder the 'countrynewwb' factor based on the specified order
internet_use$countrynewwb <- factor(internet_use$countrynewwb, levels = rev(order_levels))

# Create the combined graph with fixed x-axis limits
ggplot(internet_use, aes(
  x = int_value,
  y = countrynewwb,
  color = group2
)) +
  geom_line(aes(group = interaction(countrynewwb, group_type)), color = "grey70", size = 0.7, color = "black") +  # Connect dots within each country
  geom_point(aes(color = group2), size = 4) +
  geom_point(size = 4, shape = 1, color = "black") +
  scale_color_manual(
    values = c(
      "women" = "#5696D0", "men" = "#8066AC",
      "poorest 40%" = "#5696D0", "richest 60%" = "#8066AC"
    ),
    labels = c(
      "women" = "Women",
      "men" = "Men",
      "poorest 40%" = "Lowest 40%", 
      "richest 60%" = "Wealthiest 60%"
    )
  ) +
  facet_grid(. ~ group_type, scales = "fixed", space = "free_x", 
             labeller = labeller(countrynewwb = function(x) str_wrap(x, width = 15))) + 
  scale_y_discrete(labels = wrap_format(18)) +
  xlim(0, 100) +  # Enforce x-axis limits from 0 to 100
  labs(
    caption = "Source: Global Findex Database 2025",
    title = "Internet use is widespread, though there are gaps by income and gender ",
    subtitle = "Adults who used the internet in the past three months (%), 2024",
    color = NULL  # No global legend title
  ) +
  theme_bw() +  # Use white background
  theme(
    panel.grid = element_blank(),
    panel.background = element_blank(),
    axis.title.y = element_blank(),
    axis.title.x = element_blank(),
    plot.title.position = "plot",
    axis.text.x = element_text(family = "Nunito Sans", size = 16, color = "black"),
    axis.text.y = element_text(family = "Nunito Sans", size = 16, color = "black", hjust = 0),
    axis.ticks = element_blank(),
    plot.title = element_text(size = 18, family = "Nunito Sans", face = "bold", hjust = 0),
    plot.subtitle = element_text(size = 16, family = "Nunito Sans", hjust = 0, margin = margin(b = 10)),
    legend.title = element_blank(),
    legend.text = element_text(size = 16, family = "Nunito Sans"),
    legend.position = "bottom",
    legend.spacing.x = unit(0.25, "cm"),
    strip.text = element_text(size = 16, family = "Nunito Sans", face = "bold", color = "black"),
    strip.background = element_blank(),
    panel.spacing = unit(1, "lines"),
    plot.margin = margin(t = 10, r = 20, b = 10, l = 10),
    panel.border = element_blank(),
    plot.caption = element_text(hjust = 0,
                                size = 12,
                                family = "Nunito Sans"),
    plot.caption.position = "plot") +
  geom_vline(xintercept = 100, color = "#C2C0C0", size = 0.5, linetype = "solid")

# Save the plot with a white background
ggsave(
  filename = file.path(folder_path, sprintf("int_gap_gender_income.png")),
  width = width_num+1,
  height = height_num+2,
  units = "in",
  device = 'png',
  dpi = 120)
