# Create the dataset for visualization
Diff_Internet_LAC <- data %>% 
  filter(group == "gender") %>%  # Change group filter to "women"
  filter(year == 2024) %>% 
  filter(countrynewwb %in% c_region) %>% 
  select(countrynewwb, group2, con_internet3, con_internet_sp) %>% 
  filter(!is.na(con_internet3)) %>% 
  mutate(
    "gap1" = con_internet_sp,  
    "gap2" = con_internet3 - con_internet_sp,
    "total" = con_internet3
  ) %>% 
  gather(group, value, gap1, gap2) %>%
  filter(!is.na(group), !is.na(value)) %>%
  mutate(total = total * 100,
         value = value * 100,
         lab = ifelse(group == "gap1", round(total), NA)) %>%
  filter(!is.na(total))

# Check the number of unique countries in dataset
length_unique_countries <- Diff_Internet_LAC %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Set width and height dynamically
if (length_unique_countries < 8) {
  width_num <- 8
  height_num <- 4
} else {
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# Compute max value for x-axis safely
max_val <- Diff_Internet_LAC$total %>% 
  max(na.rm = TRUE) 

# Ensure max_val is a finite number
if (is.finite(max_val)) {
  max_val <- max_val + 15
  if (max_val > 92) {
    max_val <- 110
  }
} else {
  max_val <- 100  # Default fallback value
}

Diff_Internet_LAC <- Diff_Internet_LAC %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))

# Create the plot
ggplot(Diff_Internet_LAC) +
  geom_bar(aes(y = factor(group2, levels = c("men", "women")),
               x = value,
               fill = factor(group, levels = c("gap2", "gap1"))),
           stat = "identity", 
           position = "stack",
           width = 0.79,
           color = "black") +
  
  scale_fill_manual(values = c("gap1" = "#D12891",  
                               "gap2" = "#CCCCCC"), 
                    breaks = c("gap1", "gap2"),
                    labels = c("Own a smartphone", "Do not own a smartphone")) +
  
  scale_x_continuous(limits = c(0, max_val),
                     breaks = seq(0, max_val, by = 20)) +
  scale_y_discrete(labels = function(x) str_to_title(x)) +

  facet_grid(factor(countrynewwb) ~ ., 
             scales = "free", 
             space = "free", 
             switch = "both", 
             labeller = label_wrap_gen(width = 37, multi_line = TRUE)) +

  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(size = 18, family = "Nunito Sans", colour = "black", angle = 0, hjust = 0),
    strip.text.x = element_text(size = 18, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'left',
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 18),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 18),
    axis.text.y.left = element_text(family = "Nunito Sans", color = "black", size = 18),
    axis.ticks.y = element_blank(),
    axis.ticks.x = element_line(color = "black"),
    plot.subtitle = element_text(size = 20, family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 20, family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 18, family = "Nunito Sans"),
    legend.text.align = 0,
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0, size = 14, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +

  guides(fill = guide_legend(nrow = 2, byrow = TRUE)) +

  labs(
    caption = "Source: Global Findex Database 2025",
    title = "91 percent of smartphone owners use the internet",
    subtitle = "Adults who used the internet in the past three months (%), 2024"
  )

# Export the image
ggsave(
  filename = file.path(folder_path, ("5302_internet_diff_gender_region.png")),
  width = 12,
  height = 6,
  device = 'png',
  dpi = 120
)
