
# Load necessary libraries
library(ggplot2)
library(dplyr)
library(tidyr)
library(scales)
library(stringr)
library(forcats)

### Latin America and the Caribbean

nophone_reason_data <- data %>%
  filter(year == 2024) %>%
  filter(group %in% c("all", "gender", "income")) %>%
  filter(countrynewwb %in% c("Latin America & Caribbean (excluding high income)")) %>%
  select(countrynewwb, group, group2, con9_all_basic, con31a_nsp, con31b_nsp, con31c_nsp, con31d_nsp,
         con31e_nsp, con31f_nsp, con31g_nsp, con31h_nsp,
         con32_nsp_mon, con32_nsp_exp, con32_nsp_cov, con32_nsp_typ,
         con32_nsp_fam, con32_nsp_sec, con32_nsp_els, con32_nsp_need) %>%
  filter(!is.na(con9_all_basic)) %>%
  group_by(group2) %>%
  ungroup() 


indicator_mapping <- data.frame(
  indicator = c("con31a_nsp", "con31b_nsp", "con31c_nsp", "con31d_nsp",
                "con31e_nsp", "con31f_nsp", "con31g_nsp", "con31h_nsp",
                "con32_nsp_mon", "con32_nsp_exp", "con32_nsp_cov", "con32_nsp_typ",
                "con32_nsp_fam", "con32_nsp_sec", "con32_nsp_els", "con32_nsp_need"),
  reasons_any_label = c(
    "Do not have enough money for a device",
    "Buying mobile minutes is too expensive",
    "No reliable coverage",
    "Difficulty reading or typing",
    "Family or community disapproval",
    "Personal safety or security concerns",
    "Use someone else's phone",
    "No need for a smartphone",
    "Do not have enough money for a device",
    "Buying mobile minutes is too expensive",
    "No reliable coverage",
    "Difficulty reading or typing",
    "Family or community disapproval",
    "Personal safety or security concerns",
    "Use someone else's phone",
    "No need for a smartphone"
  )
)

nophone_reason_data <- nophone_reason_data %>%
  pivot_longer(cols = starts_with("con") & !starts_with("con9"),
               names_to = "indicator",
               values_to = "value") %>%
  filter(!is.na(value))

nophone_reason_data <- nophone_reason_data %>%
  left_join(indicator_mapping, by = "indicator")


main_reasons <- c("con32_nsp_mon", "con32_nsp_exp", "con32_nsp_cov", "con32_nsp_typ",
                  "con32_nsp_fam", "con32_nsp_sec", "con32_nsp_els", "con32_nsp_need")

any_reasons <- c("con31a_nsp", "con31b_nsp", "con31c_nsp", "con31d_nsp",
                 "con31e_nsp", "con31f_nsp", "con31g_nsp", "con31h_nsp")

nophone_reason_data <- nophone_reason_data %>%
  mutate(
    reason_type = case_when(
      indicator %in% main_reasons ~ "Main reason",
      indicator %in% any_reasons ~ "Any reason",
      TRUE ~ "Other"  # You can adjust this part if you have more categories
    )
  )

# Convert the 'Value' column to percentages (multiply by 100)
nophone_reason_data <- nophone_reason_data %>%
  mutate(value = value * 100)

# Find the min and max values of 'Value' for proper scaling
min_value <- min(nophone_reason_data$value, na.rm = TRUE)
max_value <- max(nophone_reason_data$value, na.rm = TRUE)


nophone_reason_data <- nophone_reason_data %>%
  mutate(group2 = recode(group2, 
                         "all" = "All",
                         "women" = "Women",
                         "men" = "Men",
                         "poorest 40%" = "Poorest 40%",
                         "richest 60%" = "Wealthiest 60%",
                         "rural" = "Rural",
                         "urban" = "Urban"))

group_order <- c("All", "Women", "Men", "Poorest 40%", "Wealthiest 60%", "Rural", "Urban")
nophone_reason_data <- nophone_reason_data %>%
  mutate(group2 = factor(group2, levels = group_order))

# Add the phone ownership percentage (con1_all) next to the country name
nophone_reason_data <- nophone_reason_data %>%
  group_by(group2) %>%
  mutate(
    country_label = group2
    # paste0(group2, " (", ifelse(!is.na(con9_all_basic), paste0(round(con9_all_basic * 100), "%"), "None"), ")")
  ) %>%
  ungroup() %>%
  filter(!is.na(con9_all_basic)) %>%
  mutate(country_label = factor(country_label, levels = unique(country_label[order(group2)])))

# Define the correct order for reasons_any_label
reason_order <- c(
  "Do not have enough money for a device",
  "Buying mobile minutes is too expensive",
  "Difficulty reading or typing",
  "No reliable coverage",
  "No need for a smartphone",
  "Personal safety or security concerns",
  "Use someone else's phone",
  "Family or community disapproval"
)

nophone_reason_data <- nophone_reason_data %>%
  mutate(reasons_any_label = factor(reasons_any_label, levels = reason_order))

heatmap_plot <- ggplot(nophone_reason_data, aes(x = reason_type,
                                                y = forcats::fct_rev(country_label),  
                                                fill = value)) +
  geom_tile(color = "black") +  # Tile borders
  scale_fill_gradient2(high = "#D3172A", mid = "#E9867D", low = "#C2C0C0", 
                       midpoint = (max_value + min_value) / 2, 
                       limits = c(min_value, max_value), 
                       name = "Value (%)",
                       labels = label_percent(scale = 1)) +  # Format the legend as percentages
  geom_text(aes(label = paste0(round(value), "%")), color = "black", size = 10) +  # Add percentage labels
  
  # Keep the main and any reasons together and reorder based on reason_type
  facet_wrap(~ reasons_any_label, scales = "free_x", nrow = 1, 
             labeller = labeller(reasons_any_label = function(x) str_wrap(x, width = 15))) +
  
  # Modify reason_type labels directly here instead of using str_to_title
  scale_x_discrete(position = "top") +
  
  labs(
    caption = "Source: Global Findex Database 2025\nNote: Numbers in parentheses represent the share of adults who do not own a smartphone.",
    title = "Lack of money to buy a smartphone is the biggest barrier to smartphone ownership, and therefore to internet use",
    subtitle = "Adults without a smartphone (%), 2024"
  ) +
  
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0, hjust = 0, size = 28),  # Reduce size of y facet labels
    strip.text.x = element_text(size = 28, family = "Nunito Sans", colour = "black", angle = 0),  # Reduce size of x facet labels
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.text = element_text(hjust = 0, size = 28, family = "Nunito Sans"),  # Adjust legend text size here
    legend.justification = 'center',
    legend.key.size = unit(4, "mm"),
    legend.key.width = unit(2, "cm"),  # Increase width of legend key
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 28, hjust = 0),  # Adjust y-axis text size
    axis.ticks.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 22, face = "bold"),  # Adjust x-axis text size
    axis.ticks.x = element_blank(),
    plot.subtitle = element_text(size = 28, family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 28, family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    plot.caption = element_text(hjust = 0, size = 24, family = "Nunito Sans"),
    plot.caption.position = "plot"
  )

# Display the plot
print(heatmap_plot)

# Export the image
ggsave(
  filename = file.path(folder_path, ("1.2.7a.png")),
  width = 27,
  height = 9,
  units = "in",
  device = 'png',
  dpi = 120)

# ggsave(
#   filename = file.path(folder_path, ("1.2.7a.eps")),
#   width = 27,
#   height = 9,
#   units = "in",
#   device = 'eps',
#   dpi = 120)

### Middle East and North Africa

nophone_reason_data <- data %>%
  filter(year == 2024) %>%
  filter(group %in% c("all", "gender", "income")) %>%
  filter(countrynewwb %in% c("Middle East & North Africa (excluding high income)")) %>%
  select(countrynewwb, group, group2, con9_all_basic, con31a_nsp, con31b_nsp, con31c_nsp, con31d_nsp,
         con31e_nsp, con31f_nsp, con31g_nsp, con31h_nsp,
         con32_nsp_mon, con32_nsp_exp, con32_nsp_cov, con32_nsp_typ,
         con32_nsp_fam, con32_nsp_sec, con32_nsp_els, con32_nsp_need) %>%
  filter(!is.na(con9_all_basic)) %>%
  group_by(group2) %>%
  ungroup() 


indicator_mapping <- data.frame(
  indicator = c("con31a_nsp", "con31b_nsp", "con31c_nsp", "con31d_nsp",
                "con31e_nsp", "con31f_nsp", "con31g_nsp", "con31h_nsp",
                "con32_nsp_mon", "con32_nsp_exp", "con32_nsp_cov", "con32_nsp_typ",
                "con32_nsp_fam", "con32_nsp_sec", "con32_nsp_els", "con32_nsp_need"),
  reasons_any_label = c(
    "Do not have enough money for a device",
    "Buying mobile minutes is too expensive",
    "No reliable coverage",
    "Difficulty reading or typing",
    "Family or community disapproval",
    "Personal safety or security concerns",
    "Use someone else's phone",
    "No need for a smartphone",
    "Do not have enough money for a device",
    "Buying mobile minutes is too expensive",
    "No reliable coverage",
    "Difficulty reading or typing",
    "Family or community disapproval",
    "Personal safety or security concerns",
    "Use someone else's phone",
    "No need for a smartphone"
  )
)

nophone_reason_data <- nophone_reason_data %>%
  pivot_longer(cols = starts_with("con") & !starts_with("con9"),
               names_to = "indicator",
               values_to = "value") %>%
  filter(!is.na(value))

nophone_reason_data <- nophone_reason_data %>%
  left_join(indicator_mapping, by = "indicator")


main_reasons <- c("con32_nsp_mon", "con32_nsp_exp", "con32_nsp_cov", "con32_nsp_typ",
                  "con32_nsp_fam", "con32_nsp_sec", "con32_nsp_els", "con32_nsp_need")

any_reasons <- c("con31a_nsp", "con31b_nsp", "con31c_nsp", "con31d_nsp",
                 "con31e_nsp", "con31f_nsp", "con31g_nsp", "con31h_nsp")

nophone_reason_data <- nophone_reason_data %>%
  mutate(
    reason_type = case_when(
      indicator %in% main_reasons ~ "Main reason",
      indicator %in% any_reasons ~ "Any reason",
      TRUE ~ "Other"  # You can adjust this part if you have more categories
    )
  )

# Convert the 'Value' column to percentages (multiply by 100)
nophone_reason_data <- nophone_reason_data %>%
  mutate(value = value * 100)

# Find the min and max values of 'Value' for proper scaling
min_value <- min(nophone_reason_data$value, na.rm = TRUE)
max_value <- max(nophone_reason_data$value, na.rm = TRUE)


nophone_reason_data <- nophone_reason_data %>%
  mutate(group2 = recode(group2, 
                         "all" = "All",
                         "women" = "Women",
                         "men" = "Men",
                         "poorest 40%" = "Poorest 40%",
                         "richest 60%" = "Wealthiest 60%",
                         "rural" = "Rural",
                         "urban" = "Urban"))

group_order <- c("All", "Women", "Men", "Poorest 40%", "Wealthiest 60%", "Rural", "Urban")
nophone_reason_data <- nophone_reason_data %>%
  mutate(group2 = factor(group2, levels = group_order))

# Add the phone ownership percentage (con1_all) next to the country name
nophone_reason_data <- nophone_reason_data %>%
  group_by(group2) %>%
  mutate(
    country_label = group2
    # paste0(group2, " (", ifelse(!is.na(con9_all_basic), paste0(round(con9_all_basic * 100), "%"), "None"), ")")
  ) %>%
  ungroup() %>%
  filter(!is.na(con9_all_basic)) %>%
  mutate(country_label = factor(country_label, levels = unique(country_label[order(group2)])))

# Define the correct order for reasons_any_label
reason_order <- c(
  "Do not have enough money for a device",
  "Buying mobile minutes is too expensive",
  "Difficulty reading or typing",
  "No reliable coverage",
  "No need for a smartphone",
  "Personal safety or security concerns",
  "Use someone else's phone",
  "Family or community disapproval"
)

nophone_reason_data <- nophone_reason_data %>%
  mutate(reasons_any_label = factor(reasons_any_label, levels = reason_order))

heatmap_plot <- ggplot(nophone_reason_data, aes(x = reason_type,
                                                y = forcats::fct_rev(country_label),  
                                                fill = value)) +
  geom_tile(color = "black") +  # Tile borders
  scale_fill_gradient2(high = "#D3172A", mid = "#E9867D", low = "#C2C0C0", 
                       midpoint = (max_value + min_value) / 2, 
                       limits = c(min_value, max_value), 
                       name = "Value (%)",
                       labels = label_percent(scale = 1)) +  # Format the legend as percentages
  geom_text(aes(label = paste0(round(value), "%")), color = "black", size = 10) +  # Add percentage labels
  
  # Keep the main and any reasons together and reorder based on reason_type
  facet_wrap(~ reasons_any_label, scales = "free_x", nrow = 1, 
             labeller = labeller(reasons_any_label = function(x) str_wrap(x, width = 15))) +
  
  # Modify reason_type labels directly here instead of using str_to_title
  scale_x_discrete(position = "top") +
  
  labs(
    caption = "Source: Global Findex Database 2025\nNote: Numbers in parentheses represent the share of adults who do not own a smartphone.",
    title = "Lack of money to buy a smartphone is the biggest barrier to smartphone ownership, and therefore to internet use",
    subtitle = "Adults without a smartphone (%), 2024"
  ) +
  
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0, hjust = 0, size = 28),  # Reduce size of y facet labels
    strip.text.x = element_text(size = 28, family = "Nunito Sans", colour = "black", angle = 0),  # Reduce size of x facet labels
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.text = element_text(hjust = 0, size = 28, family = "Nunito Sans"),  # Adjust legend text size here
    legend.justification = 'center',
    legend.key.size = unit(4, "mm"),
    legend.key.width = unit(2, "cm"),  # Increase width of legend key
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 28, hjust = 0),  # Adjust y-axis text size
    axis.ticks.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 22, face = "bold"),  # Adjust x-axis text size
    axis.ticks.x = element_blank(),
    plot.subtitle = element_text(size = 28, family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 28, family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    plot.caption = element_text(hjust = 0, size = 24, family = "Nunito Sans"),
    plot.caption.position = "plot"
  )

# Display the plot
print(heatmap_plot)

# Export the image
ggsave(
  filename = file.path(folder_path, ("1.2.7b.png")),
  width = 27,
  height = 9,
  units = "in",
  device = 'png',
  dpi = 120)

# ggsave(
#   filename = file.path(folder_path, ("1.2.7b.eps")),
#   width = 27,
#   height = 9,
#   units = "in",
#   device = 'eps',
#   dpi = 120)

### South Asia 

nophone_reason_data <- data %>%
  filter(year == 2024) %>%
  filter(group %in% c("all", "gender", "income")) %>%
  filter(countrynewwb %in% c("South Asia (excluding high income)")) %>%
  select(countrynewwb, group, group2, con9_all_basic, con31a_nsp, con31b_nsp, con31c_nsp, con31d_nsp,
         con31e_nsp, con31f_nsp, con31g_nsp, con31h_nsp,
         con32_nsp_mon, con32_nsp_exp, con32_nsp_cov, con32_nsp_typ,
         con32_nsp_fam, con32_nsp_sec, con32_nsp_els, con32_nsp_need) %>%
  filter(!is.na(con9_all_basic)) %>%
  group_by(group2) %>%
  ungroup() 


indicator_mapping <- data.frame(
  indicator = c("con31a_nsp", "con31b_nsp", "con31c_nsp", "con31d_nsp",
                "con31e_nsp", "con31f_nsp", "con31g_nsp", "con31h_nsp",
                "con32_nsp_mon", "con32_nsp_exp", "con32_nsp_cov", "con32_nsp_typ",
                "con32_nsp_fam", "con32_nsp_sec", "con32_nsp_els", "con32_nsp_need"),
  reasons_any_label = c(
    "Do not have enough money for a device",
    "Buying mobile minutes is too expensive",
    "No reliable coverage",
    "Difficulty reading or typing",
    "Family or community disapproval",
    "Personal safety or security concerns",
    "Use someone else's phone",
    "No need for a smartphone",
    "Do not have enough money for a device",
    "Buying mobile minutes is too expensive",
    "No reliable coverage",
    "Difficulty reading or typing",
    "Family or community disapproval",
    "Personal safety or security concerns",
    "Use someone else's phone",
    "No need for a smartphone"
  )
)

nophone_reason_data <- nophone_reason_data %>%
  pivot_longer(cols = starts_with("con") & !starts_with("con9"),
               names_to = "indicator",
               values_to = "value") %>%
  filter(!is.na(value))

nophone_reason_data <- nophone_reason_data %>%
  left_join(indicator_mapping, by = "indicator")


main_reasons <- c("con32_nsp_mon", "con32_nsp_exp", "con32_nsp_cov", "con32_nsp_typ",
                  "con32_nsp_fam", "con32_nsp_sec", "con32_nsp_els", "con32_nsp_need")

any_reasons <- c("con31a_nsp", "con31b_nsp", "con31c_nsp", "con31d_nsp",
                 "con31e_nsp", "con31f_nsp", "con31g_nsp", "con31h_nsp")

nophone_reason_data <- nophone_reason_data %>%
  mutate(
    reason_type = case_when(
      indicator %in% main_reasons ~ "Main reason",
      indicator %in% any_reasons ~ "Any reason",
      TRUE ~ "Other"  # You can adjust this part if you have more categories
    )
  )

# Convert the 'Value' column to percentages (multiply by 100)
nophone_reason_data <- nophone_reason_data %>%
  mutate(value = value * 100)

# Find the min and max values of 'Value' for proper scaling
min_value <- min(nophone_reason_data$value, na.rm = TRUE)
max_value <- max(nophone_reason_data$value, na.rm = TRUE)


nophone_reason_data <- nophone_reason_data %>%
  mutate(group2 = recode(group2, 
                         "all" = "All",
                         "women" = "Women",
                         "men" = "Men",
                         "poorest 40%" = "Poorest 40%",
                         "richest 60%" = "Wealthiest 60%",
                         "rural" = "Rural",
                         "urban" = "Urban"))

group_order <- c("All", "Women", "Men", "Poorest 40%", "Wealthiest 60%", "Rural", "Urban")
nophone_reason_data <- nophone_reason_data %>%
  mutate(group2 = factor(group2, levels = group_order))

# Add the phone ownership percentage (con1_all) next to the country name
nophone_reason_data <- nophone_reason_data %>%
  group_by(group2) %>%
  mutate(
    country_label = group2
      # paste0(group2, " (", ifelse(!is.na(con9_all_basic), paste0(round(con9_all_basic * 100), "%"), "None"), ")")
  ) %>%
  ungroup() %>%
  filter(!is.na(con9_all_basic)) %>%
  mutate(country_label = factor(country_label, levels = unique(country_label[order(group2)])))

# Define the correct order for reasons_any_label
reason_order <- c(
  "Do not have enough money for a device",
  "Buying mobile minutes is too expensive",
  "Difficulty reading or typing",
  "No reliable coverage",
  "No need for a smartphone",
  "Personal safety or security concerns",
  "Use someone else's phone",
  "Family or community disapproval"
)

nophone_reason_data <- nophone_reason_data %>%
  mutate(reasons_any_label = factor(reasons_any_label, levels = reason_order))

heatmap_plot <- ggplot(nophone_reason_data, aes(x = reason_type,
                                                y = forcats::fct_rev(country_label),  
                                                fill = value)) +
  geom_tile(color = "black") +  # Tile borders
  scale_fill_gradient2(high = "#D3172A", mid = "#E9867D", low = "#C2C0C0", 
                       midpoint = (max_value + min_value) / 2, 
                       limits = c(min_value, max_value), 
                       name = "Value (%)",
                       labels = label_percent(scale = 1)) +  # Format the legend as percentages
  geom_text(aes(label = paste0(round(value), "%")), color = "black", size = 10) +  # Add percentage labels
  
  # Keep the main and any reasons together and reorder based on reason_type
  facet_wrap(~ reasons_any_label, scales = "free_x", nrow = 1, 
             labeller = labeller(reasons_any_label = function(x) str_wrap(x, width = 15))) +
  
  # Modify reason_type labels directly here instead of using str_to_title
  scale_x_discrete(position = "top") +
  
  labs(
    caption = "Source: Global Findex Database 2025\nNote: Numbers in parentheses represent the share of adults who do not own a smartphone.",
    title = "Lack of money to buy a smartphone is the biggest barrier to smartphone ownership, and therefore to internet use",
    subtitle = "Adults without a smartphone (%), 2024"
  ) +
  
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0, hjust = 0, size = 28),  # Reduce size of y facet labels
    strip.text.x = element_text(size = 28, family = "Nunito Sans", colour = "black", angle = 0),  # Reduce size of x facet labels
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.text = element_text(hjust = 0, size = 28, family = "Nunito Sans"),  # Adjust legend text size here
    legend.justification = 'center',
    legend.key.size = unit(4, "mm"),
    legend.key.width = unit(2, "cm"),  # Increase width of legend key
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 28, hjust = 0),  # Adjust y-axis text size
    axis.ticks.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 22, face = "bold"),  # Adjust x-axis text size
    axis.ticks.x = element_blank(),
    plot.subtitle = element_text(size = 28, family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 28, family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    plot.caption = element_text(hjust = 0, size = 24, family = "Nunito Sans"),
    plot.caption.position = "plot"
  )

# Display the plot
print(heatmap_plot)

# Export the image
ggsave(
  filename = file.path(folder_path, ("1.2.7c.png")),
  width = 27,
  height = 9,
  units = "in",
  device = 'png',
  dpi = 120)

# ggsave(
#   filename = file.path(folder_path, ("1.2.7c.eps")),
#   width = 27,
#   height = 9,
#   units = "in",
#   device = 'eps',
#   dpi = 120)

### Sub-Saharan Africa

nophone_reason_data <- data %>%
  filter(year == 2024) %>%
  filter(group %in% c("all", "gender", "income")) %>%
  filter(countrynewwb %in% c("Sub-Saharan Africa (excluding high income)")) %>%
  select(countrynewwb, group, group2, con9_all_basic, con31a_nsp, con31b_nsp, con31c_nsp, con31d_nsp,
         con31e_nsp, con31f_nsp, con31g_nsp, con31h_nsp,
         con32_nsp_mon, con32_nsp_exp, con32_nsp_cov, con32_nsp_typ,
         con32_nsp_fam, con32_nsp_sec, con32_nsp_els, con32_nsp_need) %>%
  filter(!is.na(con9_all_basic)) %>%
  group_by(group2) %>%
  ungroup() 


indicator_mapping <- data.frame(
  indicator = c("con31a_nsp", "con31b_nsp", "con31c_nsp", "con31d_nsp",
                "con31e_nsp", "con31f_nsp", "con31g_nsp", "con31h_nsp",
                "con32_nsp_mon", "con32_nsp_exp", "con32_nsp_cov", "con32_nsp_typ",
                "con32_nsp_fam", "con32_nsp_sec", "con32_nsp_els", "con32_nsp_need"),
  reasons_any_label = c(
    "Do not have enough money for a device",
    "Buying mobile minutes is too expensive",
    "No reliable coverage",
    "Difficulty reading or typing",
    "Family or community disapproval",
    "Personal safety or security concerns",
    "Use someone else's phone",
    "No need for a smartphone",
    "Do not have enough money for a device",
    "Buying mobile minutes is too expensive",
    "No reliable coverage",
    "Difficulty reading or typing",
    "Family or community disapproval",
    "Personal safety or security concerns",
    "Use someone else's phone",
    "No need for a smartphone"
  )
)

nophone_reason_data <- nophone_reason_data %>%
  pivot_longer(cols = starts_with("con") & !starts_with("con9"),
               names_to = "indicator",
               values_to = "value") %>%
  filter(!is.na(value))

nophone_reason_data <- nophone_reason_data %>%
  left_join(indicator_mapping, by = "indicator")


main_reasons <- c("con32_nsp_mon", "con32_nsp_exp", "con32_nsp_cov", "con32_nsp_typ",
                  "con32_nsp_fam", "con32_nsp_sec", "con32_nsp_els", "con32_nsp_need")

any_reasons <- c("con31a_nsp", "con31b_nsp", "con31c_nsp", "con31d_nsp",
                 "con31e_nsp", "con31f_nsp", "con31g_nsp", "con31h_nsp")

nophone_reason_data <- nophone_reason_data %>%
  mutate(
    reason_type = case_when(
      indicator %in% main_reasons ~ "Main reason",
      indicator %in% any_reasons ~ "Any reason",
      TRUE ~ "Other"  # You can adjust this part if you have more categories
    )
  )

# Convert the 'Value' column to percentages (multiply by 100)
nophone_reason_data <- nophone_reason_data %>%
  mutate(value = value * 100)

# Find the min and max values of 'Value' for proper scaling
min_value <- min(nophone_reason_data$value, na.rm = TRUE)
max_value <- max(nophone_reason_data$value, na.rm = TRUE)


nophone_reason_data <- nophone_reason_data %>%
  mutate(group2 = recode(group2, 
                         "all" = "All",
                         "women" = "Women",
                         "men" = "Men",
                         "poorest 40%" = "Poorest 40%",
                         "richest 60%" = "Wealthiest 60%",
                         "rural" = "Rural",
                         "urban" = "Urban"))

group_order <- c("All", "Women", "Men", "Poorest 40%", "Wealthiest 60%", "Rural", "Urban")
nophone_reason_data <- nophone_reason_data %>%
  mutate(group2 = factor(group2, levels = group_order))

# Add the phone ownership percentage (con1_all) next to the country name
nophone_reason_data <- nophone_reason_data %>%
  group_by(group2) %>%
  mutate(
    country_label = group2
    # paste0(group2, " (", ifelse(!is.na(con9_all_basic), paste0(round(con9_all_basic * 100), "%"), "None"), ")")
  ) %>%
  ungroup() %>%
  filter(!is.na(con9_all_basic)) %>%
  mutate(country_label = factor(country_label, levels = unique(country_label[order(group2)])))

# Define the correct order for reasons_any_label
reason_order <- c(
  "Do not have enough money for a device",
  "Buying mobile minutes is too expensive",
  "Difficulty reading or typing",
  "No reliable coverage",
  "No need for a smartphone",
  "Personal safety or security concerns",
  "Use someone else's phone",
  "Family or community disapproval"
)

nophone_reason_data <- nophone_reason_data %>%
  mutate(reasons_any_label = factor(reasons_any_label, levels = reason_order))

heatmap_plot <- ggplot(nophone_reason_data, aes(x = reason_type,
                                                y = forcats::fct_rev(country_label),  
                                                fill = value)) +
  geom_tile(color = "black") +  # Tile borders
  scale_fill_gradient2(high = "#D3172A", mid = "#E9867D", low = "#C2C0C0", 
                       midpoint = (max_value + min_value) / 2, 
                       limits = c(min_value, max_value), 
                       name = "Value (%)",
                       labels = label_percent(scale = 1)) +  # Format the legend as percentages
  geom_text(aes(label = paste0(round(value), "%")), color = "black", size = 10) +  # Add percentage labels
  
  # Keep the main and any reasons together and reorder based on reason_type
  facet_wrap(~ reasons_any_label, scales = "free_x", nrow = 1, 
             labeller = labeller(reasons_any_label = function(x) str_wrap(x, width = 15))) +
  
  # Modify reason_type labels directly here instead of using str_to_title
  scale_x_discrete(position = "top") +
  
  labs(
    caption = "Source: Global Findex Database 2025\nNote: Numbers in parentheses represent the share of adults who do not own a smartphone.",
    title = "Lack of money to buy a smartphone is the biggest barrier to smartphone ownership, and therefore to internet use",
    subtitle = "Adults without a smartphone (%), 2024"
  ) +
  
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0, hjust = 0, size = 28),  # Reduce size of y facet labels
    strip.text.x = element_text(size = 28, family = "Nunito Sans", colour = "black", angle = 0),  # Reduce size of x facet labels
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.text = element_text(hjust = 0, size = 28, family = "Nunito Sans"),  # Adjust legend text size here
    legend.justification = 'center',
    legend.key.size = unit(4, "mm"),
    legend.key.width = unit(2, "cm"),  # Increase width of legend key
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 28, hjust = 0),  # Adjust y-axis text size
    axis.ticks.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 22, face = "bold"),  # Adjust x-axis text size
    axis.ticks.x = element_blank(),
    plot.subtitle = element_text(size = 28, family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 28, family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    plot.caption = element_text(hjust = 0, size = 24, family = "Nunito Sans"),
    plot.caption.position = "plot"
  )

# Display the plot
print(heatmap_plot)

# Export the image
ggsave(
  filename = file.path(folder_path, ("1.2.7d.png")),
  width = 27,
  height = 9,
  units = "in",
  device = 'png',
  dpi = 120)

# ggsave(
#   filename = file.path(folder_path, ("1.2.7d.eps")),
#   width = 27,
#   height = 9,
#   units = "in",
#   device = 'eps',
#   dpi = 120)
