library(dplyr)
library(tidyr)
library(ggplot2)
library(stringr)

Purchase_data_vs_internet_Frequency <- data %>%
  filter(group == "all") %>%
  filter(year %in% c(2024)) %>%
  filter(countrynewwb %in% c_region) %>%
  select(countrynewwb, year, con28_int_d, con28_int_w, con28_int_m, con28_int_lm, con28_int_n,
         con26_int_d, con26_int_w, con26_int_m, con26_int_lm, con26_int_n) %>%
  rename(
    internet_access_d = con26_int_d,
    internet_access_w = con26_int_w,
    internet_access_m = con26_int_m,
    internet_access_lm = con26_int_lm,
    internet_access_n = con26_int_n,
    data_purchase_d = con28_int_d,
    data_purchase_w = con28_int_w,
    data_purchase_m = con28_int_m,
    data_purchase_lm = con28_int_lm,
    data_purchase_n = con28_int_n
  ) %>%
  filter(across(everything(), ~!is.na(.)))  # ???????????? NA

# ?????? long ??????
Purchase_data_vs_internet_Frequency_long_data <- Purchase_data_vs_internet_Frequency %>%
  pivot_longer(cols = starts_with("data_purchase") | starts_with("internet_access"),
               names_to = c("type", "category"),
               names_pattern = "(.*)_(.*)",
               values_to = "value") %>%
  mutate(type = factor(type, levels = c("data_purchase", "internet_access")),
         category = factor(category, levels = c("n", "lm", "m", "w", "d"), 
                           labels = c("Never", "Less than once a month", "Monthly", "Weekly", "Daily")))  # ???????????? levels

# ??????????????????
Purchase_data_vs_internet_Frequency_long_data <- Purchase_data_vs_internet_Frequency_long_data %>%
  group_by(countrynewwb, type) %>%
  complete(category = factor(c("Never", "Less than once a month", "Monthly", "Weekly", "Daily"), 
                             levels = c("Never", "Less than once a month", "Monthly", "Weekly", "Daily"))) %>%
  filter(!is.na(value)) %>%
  mutate(percentage = value / sum(value, na.rm = TRUE) * 100) %>%
  ungroup()

# ????????????
unique_countries_list <- Purchase_data_vs_internet_Frequency %>%
  distinct(countrynewwb) %>%
  pull(countrynewwb)

# ??????????????????
Purchase_data_label_data <- data %>%
  filter(group == "all", year %in% c(2024), countrynewwb %in% unique_countries_list) %>%
  select(countrynewwb, con27_all) %>%
  rename(total = con27_all)

internet_access_label_data <- data %>%
  filter(group == "all", year %in% c(2024), countrynewwb %in% unique_countries_list) %>%
  select(countrynewwb, con_internet3) %>%
  rename(total = con_internet3)

# ???????????????????????????
long_data_with_labels <- Purchase_data_vs_internet_Frequency_long_data %>%
  left_join(Purchase_data_label_data, by = "countrynewwb") %>%
  left_join(internet_access_label_data, by = "countrynewwb", suffix = c("_purchase", "_internet")) %>%
  mutate(label = case_when(
    type == "data_purchase" ~ total_purchase,
    type == "internet_access" ~ total_internet,
    TRUE ~ NA_real_
  )) %>%
  drop_na(label, total_internet, total_purchase)

long_data_with_labels$countrynewwb <- recode(long_data_with_labels$countrynewwb,
                                             "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                                             "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                                             "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                                             "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                                             "South Asia (excluding high income)" = "South Asia",
                                             "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"
)
long_data_with_labels$countrynewwb <- str_wrap(long_data_with_labels$countrynewwb, width = 15)

# ????????????
ggplot(long_data_with_labels) +
  geom_bar(aes(x = factor(type), y = percentage, fill = interaction(type, category)),
           stat = "identity", position = "stack", width = 0.75, color = "black") +
  scale_fill_manual(
    values = c(
      "data_purchase.Daily" = "#0F72BC",
      "data_purchase.Weekly" = "#5696D0",
      "data_purchase.Monthly" = "#B2D6F7",
      "data_purchase.Less than once a month" = "#D6EAF8",
      "data_purchase.Never" = "#C2C0C0",
      "internet_access.Daily" = "#D12891",
      "internet_access.Weekly" = "#F087B6",
      "internet_access.Monthly" = "#F5B9D3",
      "internet_access.Less than once a month" = "#FCD6E8",
      "internet_access.Never" = "#C2C0C0"
    ),
    breaks = c(
      "data_purchase.Daily",
      "data_purchase.Weekly",
      "data_purchase.Monthly",
      "data_purchase.Less than once a month",
      "data_purchase.Never",
      "internet_access.Daily",
      "internet_access.Weekly",
      "internet_access.Monthly",
      "internet_access.Less than once a month",
      "internet_access.Never"
    ),
    labels = c(
      "data_purchase.Daily" = "Daily",
      "data_purchase.Weekly" = "Weekly",
      "data_purchase.Monthly" = "Monthly",
      "data_purchase.Less than once a month" = "Less than once a month",
      "data_purchase.Never" = "Never",
      "internet_access.Daily" = "Daily",
      "internet_access.Weekly" = "Weekly",
      "internet_access.Monthly" = "Monthly",
      "internet_access.Less than once a month" = "Less than once a month",
      "internet_access.Never" = "Never"
    )
  ) +
  
  
  # Facet by country
  facet_grid(. ~ factor(countrynewwb), 
             scales = "free", 
             space = "free", 
             switch = "both", 
             labeller = label_wrap_gen(width = 25, multi_line = TRUE)) +
  scale_x_discrete(
    labels = function(x) {
      x <- recode(x, "data_purchase" = "Purchased data", "internet_access" = "Used the internet")
      str_wrap(x, width = 10)
    }
  ) +
  labs(
    x = NULL, y = NULL, fill = NULL,
    title = "Internet users typically use the web daily and pay for data monthly",
    subtitle = "Adults who used the internet in the previous three months (%), 2024",
    caption = "Source: Global Findex Database 2025\nNote: The height of this figure is normalized to 100% to facilitate behavioral comparisons."
  ) +
  theme(
    strip.placement = "outside",
    strip.background = element_blank(),
    strip.text = element_text(size = 16, family = "Nunito Sans"),
    panel.background = element_blank(),
    panel.grid = element_blank(),
    panel.border = element_blank(),
    axis.ticks.y = element_line(),
    axis.ticks.x = element_blank(),
    axis.text.x = element_text(size = 16, family = "Nunito Sans", color = "black"),
    axis.text.y = element_text(size = 16, family = "Nunito Sans", color = "black"),
    plot.title = element_text(size = 16, family = "Nunito Sans", face = "bold", hjust = 0),
    plot.subtitle = element_text(size = 16, family = "Nunito Sans"),
    plot.caption = element_text(size = 12, family = "Nunito Sans", hjust = 0),
    legend.text = element_text(size = 16, family = "Nunito Sans"),
    legend.position = "bottom",
    legend.justification = "center",
    legend.direction = "horizontal"
  ) +
  guides(fill = guide_legend(nrow = 2, byrow = TRUE))

ggsave(
  filename = file.path(folder_path, "int_data_freq.png"),
  width = 10,
  height = 5,
  units = "in", 
  dpi = 120
)
