library(ggplot2)
library(dplyr)
library(tidyr)

# Filter the data
Phone_Use_Diff <- data %>%
  filter(countrynewwb %in% c_region) %>%
  filter(group == "gender") %>%  # Use gender group
  filter(year == 2024) %>%
  select(countrynewwb, group2, con1_all, con20_all, con23_all) %>%
  filter(!is.na(con20_all) & !is.na(con23_all)) 

# Create mapping for labels
indicator_mapping <- data.frame(
  indicator = c("con20_all", "con23_all"),
  label = c(
    "Set rules about phone use",
    "Received offensive messages, photos, or videos"
  )
)

Phone_Use_Diff$group2 <- factor(Phone_Use_Diff$group2, levels = c("women", "men"))
Phone_Use_Diff$group2 <- recode(Phone_Use_Diff$group2, "women" = "Women", "men" = "Men")

# Reshape data to long format for con7_all and con23_all
Phone_Use_Diff_long <- Phone_Use_Diff %>%
  pivot_longer(
    cols = c(con20_all, con23_all), 
    names_to = "indicator", 
    values_to = "value"
  ) %>%
  left_join(indicator_mapping, by = "indicator")

# Define a custom labeller function to rename regions
Phone_Use_Diff <- Phone_Use_Diff %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))

Phone_Use_Diff_long <- Phone_Use_Diff_long %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))

# Create the figure with all countries in a single row and country names below
ggplot() +
  # Add the grey bar for "Phone Ownership (con1_all)" (NO LEGEND)
  geom_bar(data = Phone_Use_Diff, 
           aes(x = group2, y = con1_all * 100), 
           stat = "identity", fill = "grey70", alpha = 0.5, color = NA, show.legend = FALSE, color = "black") +
  
  # Bar chart for "Rules set about phone use" & "Received offensive messages"
  geom_bar(data = Phone_Use_Diff_long, 
           aes(x = group2, y = value * con1_all * 100, fill = indicator),  
           stat = "identity", position = position_dodge(width = 0.9), alpha = 0.9, color = "black") +

  facet_wrap(~ countrynewwb, nrow = 1, scales = "free_x", strip.position = "bottom",
             labeller = labeller(countrynewwb = function(x) str_wrap(x, width = 15))) +
  
  # Custom color scale for only the two issue-related bars
  scale_fill_manual(
    values = c("con20_all" = "#F3F2B2", "con23_all" = "#B8CB33"),  
    labels = c(
      "Set rules about phone use",
      "Received offensive messages, photos, or videos"
    )
  ) +
  
  guides(fill = guide_legend(title = NULL)) +
  theme_minimal() +
  theme(
    # legend.position = "none",
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0),
    strip.text.y = element_text(size = 16, family = "Nunito Sans"), 
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border=element_blank(),
    legend.title = element_blank(),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text( 
      family = "Nunito Sans",
      color = "black",
      hjust = 0.5,
      vjust = 0.5,
      size = 16),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_line(),
    # axis.ticks.y = element_blank(),
    plot.subtitle = element_text(size = 16,
                                 family = "Nunito Sans"),
    plot.title = element_text(hjust = 0,
                              size = 16,
                              family = "Nunito Sans",
                              face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(#hjust = 0,
      size = 16,
      family = "Nunito Sans"),
    # legend.text.align = 0,
    legend.position ="bottom",
    legend.justification='center',
    legend.direction = "horizontal",
    strip.text.x = element_text(family = "Nunito Sans",
                                color = "black",
                                size = 16),
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans"),
    plot.caption.position =  "plot") +
  guides(fill = guide_legend(nrow = 1, byrow = TRUE)) +
  labs(
    caption = "Source: Global Findex Database 2025",
    title = "Women and men both confront risks associated with digital connectivity",
    subtitle = "Adults with a phone (%), 2024"
  )

# Adjust width dynamically based on number of countries
num_countries <- length(unique(Phone_Use_Diff$countrynewwb))
plot_width <- 3 + (num_countries * 2)  # Adjust width based on number of facets

# Export the image
ggsave(
  filename = file.path(folder_path, "phone_rules_regions.png"),
  width = 9,  # Adjust dynamically
  height = 6,
  device = 'png',
  bg = "white",
  dpi = 120
)
