# library(dplyr)
# library(tidyr)
# library(ggplot2)
# library(scales)
# library(showtext)

# Set font
# font_add_google("Nunito Sans", "Nunito Sans")
# showtext_auto()

# Define mapping for display labels


# Prepare the data
data_account_phone <- data %>%
  filter(group == "all" & year == 2024 & aggregate_level %in% c("region_all", "LMIC")) %>%
  select(countrynewwb, ts_account, con1_all, con_phone_ub) %>%
  mutate(
    no_account = 1 - ts_account,
    phone_unbanked = con_phone_ub,           # Unbanked with mobile phone
    no_phone_unbanked = no_account - phone_unbanked   # Unbanked without mobile phone
  ) %>%
  pivot_longer(cols = c(phone_unbanked, no_phone_unbanked), names_to = "group", values_to = "value") %>%
  mutate(value = value * 100) %>%
  filter(!is.na(value)) %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "LMIC" = "Low- and middle-income economies",
                                "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                                "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                                "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                                "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                                "South Asia (excluding high income)" = "South Asia",
                                "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))

# Calculate max y-axis
max_val <- data_account_phone %>%
  group_by(countrynewwb) %>%
  summarise(total = sum(value, na.rm = TRUE)) %>%
  pull(total) %>%
  max(na.rm = TRUE)

if (!is.finite(max_val)) {
  max_val <- 100
} else if (max_val > 100) {
  max_val <- 120
} else {
  max_val <- max_val + 15
}


data_account_phone <- data_account_phone %>%
  mutate(countrynewwb = factor(countrynewwb, levels = c(
    "Low- and middle-income economies",
    sort(setdiff(unique(countrynewwb), "Low- and middle-income economies"))
  )))

# Plot
ggplot(data_account_phone, aes(x = countrynewwb, y = value)) +
  geom_bar(
    aes(fill = factor(group, levels = c("phone_unbanked", "no_phone_unbanked"))),  # flipped stack order
    stat = "identity",
    position = "stack",
    width = 0.75,
    color = "black",
    size = 0.75
  ) +
  scale_fill_manual(
    values = c(
      "no_phone_unbanked" = "#B8CB33",   # Gray - top
      "phone_unbanked" = "#C2C0C0"       # Green - bottom
    ),
    labels = c(
      "Do not own an account but own a mobile phone",
      "Do not own an account or a mobile phone"
    )
  ) +
  scale_y_continuous(
    limits = c(0, max_val),
    breaks = seq(0, max_val, by = 20)
  ) +
  scale_x_discrete(labels = function(x) str_wrap(x, width = 16)) +
  theme(
    panel.background = element_blank(),
    panel.grid = element_blank(),
    axis.title = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.ticks = element_blank(),
    legend.title = element_blank(),
    axis.ticks.y = element_line(color = "black"),
    axis.ticks.x = element_blank(),
    legend.position = "bottom",
    legend.text = element_text(size = 16, color = "black", family = "Nunito Sans"),
    plot.title = element_text(size = 20, face = "bold", family = "Nunito Sans", hjust = 0),
    plot.subtitle = element_text(size = 18, family = "Nunito Sans", hjust = 0),
    plot.caption = element_text(size = 16, hjust = 0, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 2, byrow = TRUE, reverse = TRUE)) +
  labs(
    title = "17 percent of adults without a financial account in low- and middle-income economies also do not own a mobile phone ",
    subtitle = "Adults with no account (%), 2024",
    caption = "Source: Global Findex Database 2025"
  )

# Save the figure
ggsave(
  filename = file.path(folder_path, "figure_0_6.png"),
  width = 11,
  height = 8,
  units = "in",
  device = 'png',
  dpi = 120
)

# ggsave(
#   filename = file.path(folder_path, "figure_0_6.eps"),
#   width = 11,
#   height = 8,
#   units = "in",
#   device = 'eps',
#   dpi = 120
# )
