
# Filter and prepare data for the required variable
int_rem <- data %>%
  filter(group == "all") %>%
  filter(year == 2024) %>%
  filter(countrynewwb %in% c_region) %>%
  select(countrynewwb, fh2a) %>%
  filter(!is.na(fh2a)) %>%
  mutate(value = fh2a * 100) %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))

# Determine width and height based on number of countries
length_unique_countries <- int_rem %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

if (length_unique_countries < 8) {
  width_num <- 8
  height_num <- 4
} else {
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# Print width and height
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

# Determine max value for y-axis
max_val <- max(int_rem$value, na.rm = TRUE) + 15
if (max_val > 92) {
  max_val <- 110
}


# Plot bar chart with legend at the bottom and black country names
ggplot(int_rem, aes(x = factor(countrynewwb), y = value, fill = "Payments")) +
  geom_bar(stat = "identity", width = 0.75, show.legend = TRUE, color = "black") +
  scale_y_continuous(limits = c(0, max_val), breaks = seq(0, max_val, by = 20)) +
  scale_fill_manual(
    name = "",  # Keeps the legend title blank
    values = c("Payments" = "#0F72BC"), 
    labels = c("Received money from relatives or friends living in a different country")
  ) +
  scale_x_discrete(labels = wrap_format(18))+
  theme(
    strip.placement = "outside",
    strip.text = element_blank(),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border=element_blank(),
    legend.title = element_blank(),
    legend.position ="bottom",
    legend.justification='center',
    legend.key.size = unit(4,"mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.ticks.y = element_line(),
    axis.ticks.x = element_blank(),
    axis.text.x = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 16),
    axis.text.y = element_text( 
                    family = "Nunito Sans",
                    color = "black",
                    size = 16),
    plot.subtitle = element_text(size = 16,
                                 color = "black",
                                 family = "Nunito Sans"),
    plot.title = element_text(hjust = 0,
                              size = 16,
                              color = "black",
                              family = "Nunito Sans",
                              face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0,
                               size = 16,
                               color = "black",
                               family = "Nunito Sans"),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0,
                                vjust = 0,
                                size = 12,
                                color = "black",
                                family = "Nunito Sans"),
    plot.caption.position =  "plot") +
  labs(
    caption = "Source: Global Findex Database 2025",
    title = "Adults in South Asia who receive remittances are more likely to say they could get extra money without \nmuch difficulty",
    subtitle = "Adults (%), 2024"
  )

# Save the plot
ggsave(
  filename = file.path(folder_path, "2120_int_rem.png"),
  width = width_num+1,
  height = height_num+2,
  device = "png",
  dpi = 120
)

