# Select a specific country (e.g., "AU_Central")
selected_country <- "LMIC"

# Filter data for the selected country
fh <- data %>%
  filter(i24 == 1, countrynewwb == selected_country) %>%
  select(countrynewwb, group, group2, year, i24, regionwb24_hi, 
         fin24_savings_VD, fin24_family_VD, fin24_working_VD, 
         fin24_loan_VD, fin24_selling_VD, fin24_other_VD, 
         fin24_savings_SD_ND, fin24_family_SD_ND, fin24_working_SD_ND, 
         fin24_loan_SD_ND, fin24_selling_SD_ND, fin24_other_SD_ND, 
         fin24_poss, fin24A_VD, fin24A_SD_ND, fin24_Nposs, fin24_dkr)

# Your existing pctclean function
pctclean <- function(x) { 
  round(x * 100, 0)
}

# Pivot data and add calculated columns
fh2 <- fh %>%
  pivot_longer(7:22) %>%
  mutate(
    source_name = case_when(
      str_detect(name, "family") ~ "Family",
      str_detect(name, "loan") ~ "Borrow",
      str_detect(name, "savings") ~ "Savings",
      str_detect(name, "work") ~ "Work",
      str_detect(name, "sell") ~ "Sale of Assets",
      str_detect(name, "other") ~ "Other", 
      TRUE ~ "Any Source"
    ),
    source_num = case_when(
      source_name == "Savings" ~ 5,
      source_name == "Borrow" ~ 4, 
      source_name == "Family" ~ 7, 
      source_name == "Work" ~ 6,
      source_name == "Sale of Assets" ~ 3,  
      source_name == "Other" ~ 2,
      source_name == "Any Source" ~ 1
    ),
    xmin = as.numeric(source_num) - 0.5,
    xmax = as.numeric(source_num) + 0.5,
    valuelabel = ifelse(source_name == "Any source", pctclean(value), NA), 
    valuelabel_sources = ifelse(source_name != "Any source", pctclean(value), NA),
    difficulty = case_when(
      str_detect(name, "SD_ND") | str_detect(name, "notvery")  ~ "ND_SD",
      str_detect(name, "VD") | str_detect(name, "very") ~ "VD",
      name == "fin24_Nposs"  ~ "IMP",
      TRUE ~ NA_character_
    ),
    difficulty_desc = case_when(
      difficulty == "ND_SD" ~ "Somewhat or not difficult at all",
      difficulty == "VD" ~ "Very difficult",
      difficulty == "IMP" ~ "Not possible",
      TRUE ~ NA_character_
    ),
    difficulty_score = case_when(
      difficulty == "VD" ~ 1,
      difficulty == "IMP" ~ 0,
      TRUE ~ NA_integer_
    ),
    group_cat_val = group
  ) %>%
  filter(!is.na(difficulty_desc)) %>%
  mutate(
    source_name = factor(source_name, 
                         levels = c("Family", "Work", "Savings", "Borrow", "Sale of Assets", "Other", "Any Source"), ordered = TRUE),
    difficulty_desc = factor(difficulty_desc, levels = c("Somewhat or not difficult at all", "Very difficult", "Not possible"))
  )

a <- fh2 %>%
  filter(source_name != "Any Source") %>%
  group_by(countrynewwb, group_cat_val, group2, source_name) %>%
  arrange(countrynewwb, group_cat_val, source_name, difficulty_desc) %>%
  group_by(countrynewwb, group_cat_val, group2) %>%
  mutate(
    upper = cumsum(value), 
    lower = lag(upper), 
    lower = ifelse(is.na(lower), 0, lower)
  )

b <- fh2 %>% 
  filter(source_name == "Any Source") %>% 
  group_by(countrynewwb, group_cat_val, group2, source_name) %>% 
  arrange(countrynewwb, group_cat_val, source_name, difficulty_desc) %>% 
  group_by(countrynewwb, group_cat_val, group2) %>%
  mutate(
    upper = cumsum(value), 
    lower = lag(upper), 
    lower = ifelse(is.na(lower), 0, lower)
  )

fh_data <- rbind(a, b) %>%
  group_by(countrynewwb, source_name, group2) %>% 
  mutate(
    valuelabpos = (upper - lower) / 2 + lower, 
    txtcolor = ifelse(difficulty_desc == "Not possible", "white", 'black')
  )

col_pal <- c("#D8E157", "#D83D35", "#15AFB7")
names(col_pal) <- c("Very difficult", "Not possible", "Somewhat or not difficult at all")

# Now recode country names only for the plot
recoded_country_names <- recode(selected_country,
                                "LMIC (exclusions)" = "low middle income economies")

# Use recoded names in the plot title
fh_data %>%
  filter(countrynewwb == selected_country, year == 2024, group_cat_val == "all", group2 != ".") %>%
  mutate(valuelabel_sources = ifelse((valuelabel_sources >= 1.51 | source_name == "Any Source"), valuelabel_sources, NA)) %>%
  ggplot(aes(x = source_num, fill = difficulty_desc, color = "black")) + 
  geom_rect(aes(ymin = lower, ymax = upper, xmin = xmin, xmax = xmax)) + 
  scale_fill_manual(values = col_pal, 
                    breaks = c("Somewhat or not difficult at all", "Very difficult", "Not possible"),
                    na.value = "grey") + 
  scale_y_continuous(limits = c(0, 1), breaks = c(0, 0.2, 0.4, 0.6, 0.8, 1), labels = c("0", "20", "40", "60", "80", "100")) + 
  scale_x_continuous(breaks = c(seq(1:7)), 
                     labels = c("Any source", "Other", "Sell assets", "Borrow", "Savings", "Work", "Family")) + 
  scale_color_identity() + 
  coord_flip() + 
  guides(fill = guide_legend(title = "Raising 5 percent of GNI per capita in 30 days is:", title.position = "top")) + 
  labs(
    title = sprintf("The share of financially resilient adults in low-and middle-income economies has increased since 2021"), 
    subtitle = "Adults identifying the source of, and assessing how difficult it would be to access, emergency money (%), 2024", 
    x = NULL,
    y = NULL, 
  ) + 
  theme(
    strip.placement = "outside",
    strip.text = element_text(size = 16, family = "Nunito Sans", colour = "black"), 
    strip.text.y.left = element_text(angle = 0),
    strip.text.x = element_text(size = 16, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    legend.box.margin = margin(0, 20, 40, -5), 
    legend.key.size = unit(4.25, "mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.ticks.y = element_blank(),
    plot.subtitle = element_text(size = 16, family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 16, family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 16, family = "Nunito Sans"),
    plot.caption = element_text(vjust = 1, hjust = 0, size = 12, family = "Nunito Sans"),
    plot.caption.position = "plot"
  )

# Save the plot
ggsave(
  filename = file.path(folder_path, sprintf("3102_waterfall_LMIC.png")), 
  width = 10, 
  height = 4, 
  units = "in", 
  device = 'png', 
  dpi = 120
)
