c_region <- c(#"High income", 
  "East Asia & Pacific (excluding high income)", "ECA (excluding Russia)",
  "Latin America & Caribbean (excluding high income)", "Middle East & North Africa (excluding high income)", 
  "South Asia (excluding high income)", "Sub-Saharan Africa (excluding high income)")

emergency_savings <- data %>%
  filter(group == "all", countrynewwb %in% c_region) %>%
  filter(year %in% c(2021, 2024)) %>%
  select(countrynewwb, year, ts_resil_savings_SD_ND) %>%
  filter(!is.na(ts_resil_savings_SD_ND)) %>%
  mutate(value = ts_resil_savings_SD_ND * 100) %>%
  filter(!is.na(value)) %>%
  mutate(
    countrynewwb = recode(countrynewwb,
                          "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                          "ECA (excluding Russia)" = "Europe and Central Asia",
                          "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                          "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                          "South Asia (excluding high income)" = "South Asia",
                          "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"
    )
  )

# Check the number of unique countries in countrynewwb
length_unique_countries <- emergency_savings %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Check list of real data set country length
if (length_unique_countries < 8) {
  width_num <- 8
  height_num <- 4 # default setting as 8 countries
} else {
  width_num <- 8 + floor((length_unique_countries - 1) / 3) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 3)
}

# Print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

max_val <- max(emergency_savings$ts_resil_savings_SD_ND, na.rm = TRUE) + 8


# Plot the data
ggplot(emergency_savings) +
  geom_bar(
    aes(x = factor(year), y = value),
    fill = "#15AFB7",
    position = "dodge",
    stat = "identity",
    width = 0.75,
    color = "black"
  ) +
  scale_y_continuous(limits = c(0, 50),
                     breaks = seq(0, 50, by = 10)) +
  scale_x_discrete(labels = scales::wrap_format(16)) +
  facet_grid(
    . ~ factor(countrynewwb, levels = order_levels),
    scales = "free",
    space = "free",
    switch = "both",
    labeller = label_wrap_gen(width = 16, multi_line = TRUE)
  ) +
  theme(
    strip.placement = "outside",
    strip.text.x = element_text(size = 16, family = "Nunito Sans", colour = "black", angle = 0),  # fix here
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "none",
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.ticks.y = element_line(),
    axis.ticks.x = element_blank(),
    plot.subtitle = element_text(size = 16, color = "black", family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 16, color = "black", family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_blank(),
    legend.key = element_blank(),
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  labs(
    caption = "Source: Global Findex Database 2025",
    subtitle = "Adults who could access savings in an emergency with little or no difficulty (%), 2021-2024",
    title = "Despite overall flat reliance on savings for extra money, some regions saw increases "
  )

ggsave(
  filename = file.path(folder_path, sprintf("4.2.3.png")),
  width = width_num+2, 
  height = height_num+2, 
  units = "in", 
  device = 'png', 
  dpi = 120
)

ggsave(
  filename = file.path(folder_path, sprintf("4.2.3.eps")),
  width = width_num+2, 
  height = height_num+2, 
  units = "in", 
  device = 'eps', 
  dpi = 120
)
