

source_of_money <- data %>%
  filter(year == 2024, group == "all") %>%
  filter(aggregate_level == "African_Union") %>%
  filter(!is.na(countrynewwb)) %>%
  select(countrynewwb, fin24_savings, fin24_family, fin24_working, 
         fin24_loan, fin24_selling, fin24_other, fin24_nomoney) %>%
  pivot_longer(cols = starts_with("fin24"), 
               names_to = "group", 
               values_to = "value") %>%
  filter(!is.na(group), !is.na(value)) %>%  # filter NA values
  # Calculate the total for each country and then standardize the values to 100%
  group_by(countrynewwb) %>%
  mutate(total = sum(value, na.rm = TRUE)) %>%  # Calculate total for each country
  mutate(value = (value / total) * 100) %>%  # Standardize to percentage
  ungroup() %>%  # Ungroup the data
  filter(!is.na(value))  # Remove rows with NA value

# Reorder the group factor so that legend order matches desired plot order
source_of_money$group <- factor(source_of_money$group,
                                levels = c("fin24_nomoney",
                                           "fin24_other",
                                           "fin24_selling",
                                           "fin24_loan",
                                           "fin24_working",
                                           "fin24_family",
                                           "fin24_savings"))

# Check the number of unique countries in countrynewwb
length_unique_countries <- source_of_money %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Adjust width and height based on the number of unique countries
if (length_unique_countries < 8) {
  width_num <- 8
  height_num <- 4 # default setting as 8 countries
} else {
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# Print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

# Check the max value for the y-axis
max_val <- max(source_of_money$value, na.rm = TRUE) + 15
if (max_val > 92) {
  max_val <- 120
}

source_of_money <- source_of_money %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "AU_Central" = "Central Africa",
                               "AU_East" = "East Africa",
                               "AU_North" = "North Africa",
                               "AU_Southern" = "Southern Africa",
                               "AU_West" = "West Africa"))

# Create the stacked bar chart
ggplot(source_of_money) +
  geom_bar(aes(y = fct_rev(factor(countrynewwb)),
               x = value,
               fill = group),
           stat = "identity", 
           position = "stack",
           width = 0.75,
           color = "black") +
  scale_fill_manual(values = c("fin24_savings" = "#0F72BC",
                               "fin24_family" = "#15AFB7", 
                               "fin24_working" = "#F48E35",
                               "fin24_loan" = "#D12891",
                               "fin24_selling" = "#A9AD05",
                               "fin24_other" = "#8066AB",
                               "fin24_nomoney" = "#cccccc"),
                    breaks = c("fin24_savings", "fin24_family", "fin24_working", 
                               "fin24_loan", "fin24_selling", "fin24_other", "fin24_nomoney"),
                    labels = c("Savings",
                               "Family or friends",
                               "Income from work",
                               "Loan",
                               "Selling goods",
                               "Other sources",
                               "Impossible to get extra money")) +
  scale_x_continuous(limits = c(0, 100),
                     breaks = seq(0, 100, by = 20)) +
  theme(
    strip.placement = "outside",
    strip.text = element_blank(),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    legend.key.size = unit(4, "mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16, hjust = 0),
    axis.ticks.x = element_line(),
    axis.ticks.y = element_blank(),
    plot.subtitle = element_text(size = 16, color = "black", family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 16, color = "black", family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 16, color = "black", family = "Nunito Sans"),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0, vjust = 0, size = 6, color = "black", family = "Nunito Sans"),
    plot.caption.position = "plot") +
  guides(fill = guide_legend(nrow = 3, byrow = TRUE)) +
  labs(
    subtitle = "Adults (%), 2024",
    title = "There is wide variation, even in the same region, in the source of extra money"
  )

ggsave(
  filename = file.path(folder_path, sprintf("source_of_funds_SSA.png")),
  width = width_num+2,
  height = height_num+1,
  device = 'png',
  dpi = 120
)
