


library(dplyr)
library(ggplot2)
library(showtext)

# Load Nunito Sans font from Google Fonts
font_add_google("Nunito Sans", "Nunito Sans")
showtext_auto()

# Define income groups to keep
selected_income_groups <- c("Low income", "Lower middle income", "Upper middle income")


# Prepare data
dot_data <- data %>%
  filter(year == 2024, group == "all") %>%
  filter(countrynewwb %in% c_list_all) %>%
  filter(incomegroupwb24 %in% selected_income_groups) %>%
  select(countrynewwb, incomegroupwb24, fin24A_SD_ND) %>%
  # select(countrynewwb, incomegroupwb24, fin24A_notdifficult) %>%
  mutate(fin24A_SD_ND = fin24A_SD_ND * 100) %>%
  filter(!is.na(fin24A_SD_ND), !is.na(incomegroupwb24))

# Reorder factor levels for y-axis
dot_data$incomegroupwb24 <- factor(dot_data$incomegroupwb24,
                                   levels = selected_income_groups)

dot_data$incomegroupwb24 <- recode(dot_data$incomegroupwb24,
                                   "Low income" = "Low-income economies",
                                   "Lower middle income" = "Lower-middle-income economies",
                                   "Upper middle income" = "Upper-middle-income economies"
                                   #"High income" = "High-income economies"
                                   )

# Define custom aqua blue-based color palette
income_colors <- c("Low-income economies" = "#BDE4E7",         
                   "Lower-middle-income economies" = "#6AC9D0", 
                   "Upper-middle-income economies" = "#15AFB7") 
                   #"High-income economies" = "#004080")        

dot_data_labels <- dot_data %>%
  group_by(incomegroupwb24) %>%
  filter(fin24A_SD_ND == min(fin24A_SD_ND, na.rm = TRUE) | fin24A_SD_ND == max(fin24A_SD_ND, na.rm = TRUE)) %>%
  ungroup()

dot_plot <- ggplot(dot_data, aes(y = fin24A_SD_ND, x = incomegroupwb24)) +
  geom_point(size = 5, shape = 21, stroke = 1.2, aes(fill = incomegroupwb24), color = "black") +
  scale_fill_manual(values = income_colors) +
  scale_y_continuous(limits = c(0, 100), breaks = seq(0, 100, 20)) +
  coord_flip() +  # Flip axes
  theme_minimal(base_family = "Nunito Sans") +
  theme(
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(size = 14, color = "black"),
    axis.text.y = element_text(size = 14, hjust = 0, color = "black"),
    axis.ticks.x = element_line(color = "black"),
    panel.grid = element_blank(),
    legend.position = "none",
    plot.title = element_text(size = 16, face = "bold", hjust = 0, color = "black"),
    plot.subtitle = element_text(size = 14, hjust = 0, color = "black"),
    plot.title.position = "plot",
    plot.margin = margin(t = 10, r = 10, b = 10, l = 10)
  ) +
  labs(
    title = "Among economies, income group is not the sole driver of financial resilience",
    subtitle = "Adults who could come up with emergency money in 30 days with some or no difficulty (%), 2024"
  ) +

  geom_text(data = dot_data_labels, 
            aes(label = countrynewwb), 
            vjust = -1.5, hjust = 0.5, size = 4, color = "black")

dot_plot
# Save the figure
ggsave(
  filename = file.path(folder_path, "emergency_money_sd_nd.png"),
  plot = dot_plot,
  width = 8,
  height = 4,
  units = "in",
  dpi = 120
)

