library(ggplot2)
library(dplyr)
library(tidyr)

# Filter the data
balance_info <- data %>%
  filter(countrynewwb %in% c_region) %>%
  filter(group == "all") %>%  # Use gender group
  filter(year == 2024) %>%
  select(countrynewwb, ts_FIaccount, fin9A_all, fin9B_all) %>%
  filter(!is.na(fin9A_all) & !is.na(fin9B_all)) 

# Create mapping for labels
indicator_mapping <- data.frame(
  indicator = c("fin9B_all", "fin9A_all"),
  label = c(
    "Checked account balance using mobile phone or computer",
    "Received information about account balance from bank on mobile phone"
  )
)


# Reshape data to long format for con7_all and con23_all
balance_info_long <- balance_info %>%
  pivot_longer(
    cols = c(fin9A_all, fin9B_all), 
    names_to = "indicator", 
    values_to = "value"
  ) %>%
  left_join(indicator_mapping, by = "indicator")


# Define a custom labeller function to rename regions
balance_info <- balance_info %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))

balance_info_long <- balance_info_long %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))

reverse_clist <- rev(sort(unique(balance_info_long$countrynewwb)))

# Create the figure with all countries in a single row and country names below
ggplot() +
  # Bar chart for "Rules set about phone use" & "Received offensive messages"
  geom_bar(data = balance_info, 
           aes(y = factor(countrynewwb, levels = reverse_clist), x =  ts_FIaccount),
           stat = "identity", position = "dodge", fill = "#C2C0C0", alpha = 0.5, color = "black") +

  geom_bar(data = balance_info_long, 
           aes(y = factor(countrynewwb, levels = reverse_clist), x = value, fill = indicator),  # Fill using 'indicator'
           stat = "identity", position = "dodge", alpha = 0.7, color = "black") +
  
  # Custom color scale for only the two issue-related bars
  scale_fill_manual(
    values = c(
      "fin9B_all" = "#D12891",
      "fin9A_all" = "#0F72BC"   
    ),
    labels = c(
      "fin9B_all" = "Checked account balance using mobile phone or computer",
      "fin9A_all" = "Received information about account balance from bank on mobile phone"
    )
  ) +
  
  scale_x_continuous(
    labels = scales::comma_format(scale = 100),  # Format as percentages
    breaks = seq(0,1, by = 0.2)  # Adjust breaks at intervals of 5% (0.05 -> 5%)
  ) +
  # Customize the theme and other aesthetics
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0),
    strip.text.x = element_text(size = 16, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'left',
    legend.key.size = unit(4, "mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16, hjust = 0),  # Set horizontal justification to 1 (left)
    axis.ticks.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.ticks.x = element_line(),
    plot.subtitle = element_text(size = 16, family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 16, family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 16, family = "Nunito Sans"),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 2, byrow = TRUE, reverse = TRUE)) +
  
  # Add labels and titles
  labs(
    title = "Adults who received information about bank account balance or checked account balance using mobile phone or computer",
    subtitle = "Adults who own a bank account (%), 2024",
    caption = "Source: Global Findex Database 2025"
  )


# Export the image
ggsave(
  filename = file.path(folder_path, "balance_info.png"),
  width = 10,  # Adjust dynamically
  height = 7,
  device = 'png',
  bg = "white",
  dpi = 120
)
