
c_region_LMIC <- c(#"High income", 
  "LMIC",
  "EAP (ex V5 countries)", "ECA (ex V5 countries)",
  "LAC (ex V5 countries)", "MENA (ex V5 countries)",
  "SAR (ex V5 countries)")

data_account_help <- data %>%
  filter(group == "all", year == 2024, countrynewwb %in% c_region_LMIC) %>%
  select(countrynewwb, ts_account, fin11_2a_all) %>%
  mutate(
    no_account = 1 - ts_account,
    fin11_2a_all = fin11_2a_all * 100,                      # Would need help
    independent = no_account * 100 - fin11_2a_all           # Would not need help (among those with no account)
  ) %>%
  pivot_longer(cols = c(fin11_2a_all, independent), names_to = "group", values_to = "value") %>%
  filter(!is.na(value)) %>%
  mutate(
    countrynewwb = recode(countrynewwb,
                          "LMIC" = "Low- and middle-income economies",
                          "EAP (ex V5 countries)" = "East Asia and Pacific",
                          "ECA (ex V5 countries)" = "Europe and Central Asia",
                          "LAC (ex V5 countries)" = "Latin America and the Caribbean",
                          "MENA (ex V5 countries)" = "Middle East and North Africa",
                          "SAR (ex V5 countries)" = "South Asia"
    )
  )
data_account_help <- data_account_help %>%
  mutate(countrynewwb = factor(countrynewwb, levels = c(
    "Low- and middle-income economies",
    sort(unique(countrynewwb[countrynewwb != "Low- and middle-income economies"]))
  )))

# Calculate safe max y-axis value
max_val <- data_account_help %>%
  group_by(countrynewwb) %>%
  summarise(total = sum(value, na.rm = TRUE)) %>%
  pull(total) %>%
  max(na.rm = TRUE)

# Fallback and adjustment
if (!is.finite(max_val)) {
  max_val <- 100
} else if (max_val > 100) {
  max_val <- 120
} else {
  max_val <- max_val + 15
}

# Plot
ggplot(data_account_help, aes(x = countrynewwb, y = value)) +
  geom_bar(
    aes(
      fill = factor(group, levels = c("independent", "fin11_2a_all"))
    ),
    stat = "identity",
    position = "stack",
    width = 0.6,
    color = "black",
    size = 0.5
  ) +
  scale_fill_manual(
    values = c(
      "fin11_2a_all" = "#5696D0",
      "independent" = "#D9D9D9"
    ),
    labels = c(
      "Would not need help of another person to use a newly opened bank account",
      "Would need help of another person to use a newly opened bank account"
    )
  ) +
  scale_y_continuous(
    limits = c(0, max_val),
    breaks = seq(0, max_val, by = 20)
  ) +
  scale_x_discrete(labels = function(x) str_wrap(x, width = 14)) +
  theme(
    strip.text.y.left = element_text(angle = 0),
    strip.text.x = element_text(size = 16, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid = element_blank(),
    axis.title = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_line(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.text = element_text(size = 16, color = "black", family = "Nunito Sans"),
    plot.title.position = "plot",
    plot.subtitle.position = "plot",
    plot.title = element_text(size = 18, face = "bold", family = "Nunito Sans", hjust = 0),
    plot.subtitle = element_text(size = 18, family = "Nunito Sans", hjust = 0),
    plot.caption = element_text(size = 16, hjust = 0, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 2, byrow = TRUE, reverse = TRUE)) +
  labs(
    title = "Two-thirds of adults without an account at a bank or similar financial institution in low- and middle-income\neconomies would need help using one",
    subtitle = "Accounts without an account at bank or similar financial institution (%), 2024",
    caption = "Source: Global Findex Database 2025"
  )

# # Save the figure
# ggsave(
#   filename = file.path(folder_path, "2.3.5.eps"),
#   width = 10,
#   height = 6,
#   units = "in",
#   device = 'eps',
#   dpi = 120
# )

ggsave(
  filename = file.path(folder_path, "4.3.6.png"),
  width = 10,
  height = 6,
  units = "in",
  device = 'png',
  dpi = 120
)