


fin_access <- data %>%
  filter(countrynewwb %in% c_list_all) %>%
  filter(group == "all") %>%
  filter(year == 2024) %>%
  filter(fin24C > 0.5) %>%
  select(countrynewwb, fin24C, fin24D_3) %>%
  filter(!is.na(fin24C)) %>%
  mutate(
    gap1 = fin24D_3,
    gap2 = fin24C - fin24D_3,
    total = fin24C
  ) %>%
  gather(group, value, gap1, gap2) %>%
  filter(!is.na(group), !is.na(value)) %>%
  mutate(
    total = total * 100,
    value = value * 100,
    lab = ifelse(group == "gap1", round(total), NA)
  ) %>%
  filter(!is.na(total)) %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))

# Check the number of unique countries
length_unique_countries <- fin_access %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Calculate width and height based on unique countries
if (length_unique_countries < 8) {
  width_num <- 8
  height_num <- 4
} else {
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

# Check max value for y-axis
max_val <- max(fin_access$total, na.rm = TRUE) + 15
if (max_val > 92) {
  max_val <- 110
}

# Create the plot
ggplot(fin_access) +
  geom_bar(
    aes(
      y = fct_rev(factor(countrynewwb)), # Y-axis: country names
      x = value,
      fill = factor(group, levels = c("gap2", "gap1"))
    ),
    stat = "identity",
    position = "stack",
    width = 0.75,
    color = "black"
  ) +
  scale_fill_manual(
    values = c("gap1" = "#B8CB33", "gap2" = "#C2C0C0"),
    breaks = c("gap1", "gap2"),
    labels = c(
      "Lost access to financial services",
      "Did not lose access to financial services"
    )
  ) +
  scale_x_continuous(
    limits = c(0, 100),
    breaks = seq(0, 100, by = 20)
  ) +
  scale_y_discrete(labels = wrap_format(32))+
  theme(
    strip.placement = "outside",
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = "center",
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(
      family = "Nunito Sans",
      color = "black",
      size =16
    ),
    axis.text.y = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 16,
      hjust = 0),
    axis.ticks.y = element_blank(),
    axis.ticks.x = element_line(color = "black"),
    plot.subtitle = element_text(size = 16, family = "Nunito Sans"),
    plot.title = element_text(
      hjust = 0,
      size = 16,
      family = "Nunito Sans",
      face = "bold"
    ),
    plot.title.position = "plot",
    legend.text = element_text(size = 16, family = "Nunito Sans"),
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 2, byrow = TRUE)) +
  labs(
    caption = "Source: Global Findex Database 2025\nNote: The economies included in this figure had 50 percent or more of adults saying they had been exposed to a natural disaster or extreme weather event in the past three years. ",
    subtitle = "Adults who experienced a natural disaster or extreme weather event in the past three years (%), 2024",
    title = "Lost access to financial services after a natural disaster or extreme weather event"
  )

# Save the plot
ggsave(
  filename = file.path(folder_path, sprintf("lost_fin_access.png")),
  width = width_num+3,
  height = height_num+1,
  device = 'png',
  dpi = 120
)
