#install.packages("patchwork")  # if not installed
library(patchwork)

exposure_data_region <- data %>%
  filter(year == 2024, group == "income", countrynewwb %in% c_region) %>%
  mutate(exposure = fin24C * 100) %>%
  filter(!is.na(exposure)) %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))

ggplot(exposure_data_region) +
  geom_bar(
    aes(
      x = factor(group2, levels = c("poorest 40%", "richest 60%")),
      y = exposure),
    fill = "#B8CB33",
    stat = "identity",
    position = "stack",
    width = 0.85,
    color = "black"
  ) +
  scale_x_discrete(
    labels = c(
      "poorest 40%" = str_wrap("Poorest 40%", width = 7),
      "richest 60%" = str_wrap("Wealthiest 60%", width = 7)
    )) +
  scale_y_continuous(limits = c(0, 100), breaks = seq(0, 100, 20)) +
  facet_grid(
    . ~ countrynewwb,
    scales = "free",
    space = "free",
    switch = "both",
    labeller = label_wrap_gen(width = 16, multi_line = TRUE)
  ) +
  labs(title = "a. Exposure to natural disasters varies by region",
       subtitle = "Adults (%), 2024",
       caption = "Source: Global Findex Database 2025\nNote: High-exposure economies are defined as economies that had 50 percent or more of adults saying they had been exposed to a natural disaster\nor extreme weather event in the past three years.") +
  theme_minimal(base_family = "Nunito Sans") +
  theme(
    strip.placement = "outside",
    strip.text.x = element_text(size = 18, family = "Nunito Sans", color = "black"),
    strip.text.y = element_blank(),
    panel.background = element_rect(fill = "white", color = NA),
    plot.background = element_rect(fill = "white", color = NA),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "none",
    legend.justification = 'left',
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.ticks.y = element_line(color = "black"),
    axis.ticks.x = element_blank(),
    plot.subtitle = element_text(size = 20, color = "black", family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 20, color = "black", family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_blank(),
    legend.key = element_blank(),
    legend.text.align = 0,
    plot.caption.position = "plot",
    plot.caption = element_text(hjust = 0, size = 14, family = "Nunito Sans")
  )

ggsave(
  filename = file.path(folder_path, "figure_sp2.1a.png"),
  width = 11, height = 7, units = "in", dpi = 120
)

# --- Plot B: High Exposure Countries ---
exposure_data_countries <- data %>%
  filter(
    year == 2024,
    group %in% c("all", "income"),
    countrynewwb %in% c_list_all
  ) %>%
  group_by(countrynewwb) %>%
  filter(
    (group == "all" & fin24C > 0.5) |
      (group == "income" & any(fin24C[group == "all"] > 0.5, na.rm = TRUE))
  ) %>%
  filter(!group == "all") %>%
  mutate(exposure = fin24C * 100) %>%
  drop_na(group2, exposure) %>%
  filter(!is.na(exposure))

ggplot(exposure_data_countries) +
  geom_bar(
    aes(
      y = factor(group2, levels = c("richest 60%", "poorest 40%")),
      x = exposure),
    fill = "#B8CB33",
    stat = "identity",
    position = "stack",
    width = 0.85,
    color = "black"
  ) +
  scale_y_discrete(
    labels = c(
      "poorest 40%" = str_wrap("Poorest 40%", width = 15),
      "richest 60%" = str_wrap("Wealthiest 60%", width = 15)
    )) +
  scale_x_continuous(limits = c(0, 100), breaks = seq(0, 100, 20)) +
  facet_grid(
    countrynewwb ~.,
    scales = "free",
    space = "free",
    switch = "both"
  ) +
  labs(title = "b. In high-exposure economies, up to 76 percent of adults reported exposure ",
       subtitle = "Adults (%), 2024",
       caption = "Source: Global Findex Database 2025\nNote: High-exposure economies are defined as economies that had 50 percent or more of adults saying they had been exposed to a \nnatural disaster or extreme weather event in the past three years.") +
  theme_minimal(base_family = "Nunito Sans") +
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(size = 18, family = "Nunito Sans", color = "black", angle = 0, hjust = 0),
    strip.text.x = element_blank(),
    panel.background = element_rect(fill = "white", color = NA),
    plot.background = element_rect(fill = "white", color = NA),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "none",
    legend.justification = 'left',
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 18),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 18),
    axis.ticks.x = element_line(color = "black"),
    axis.ticks.y = element_blank(),
    plot.subtitle = element_text(size = 20, color = "black", family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 20, color = "black", family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_blank(),
    legend.key = element_blank(),
    legend.text.align = 0,
    plot.caption.position = "plot",
    plot.caption = element_text(hjust = 0, size = 14, family = "Nunito Sans")
  )

ggsave(
  filename = file.path(folder_path, "figure_sp2.1b.png"),
  width = 10, height = 12, units = "in", dpi = 120
)
