# 3.1.6. New figure: Climate resilience

c_region <- c(#"High income", 
  "East Asia & Pacific (excluding high income)", "Europe & Central Asia (excluding high income)", 
  "Latin America & Caribbean (excluding high income)", "Middle East & North Africa (excluding high income)", 
  "South Asia (excluding high income)", "Sub-Saharan Africa (excluding high income)")


library(ggplot2)
library(dplyr)
library(tidyr)
library(stringr)


# Create the data frame
data_climate <- data %>%
  #filter(countrynewwb %in% c_list_all) %>%
  #filter(!countrynewwb %in% "Mauritius") %>%
  filter(countrynewwb %in% c_region) %>%
  filter(group == "all") %>%
  filter(year == 2024) %>%
  #filter(fin24C > 0.5) %>%
  select(countrynewwb, fin24C, fin24D_1, fin24D_2) %>%
  filter(!is.na(fin24C))

# Create the mapping for labels
indicator_mapping <- data.frame(
  indicator = c("fin24D_1", "fin24D_2"),
  label = c(
    "Suffered from loss of income",
    "Suffered from damage to home or livestock"
  )
)

# Reshape data to long format for bars
data_climate_long <- data_climate %>%
  pivot_longer(
    cols = starts_with("fin24D"), 
    names_to = "indicator", 
    values_to = "value"
  ) %>%
  left_join(indicator_mapping, by = "indicator") %>%
  mutate(label = factor(label, levels = c(
    "Suffered from loss of income",
    "Suffered from damage to home or livestock"
  )))

# Check the number of unique countries in countrynewwb
length_unique_countries <- data_climate_long %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Adjust plot size based on the number of countries
if (length_unique_countries < 8) {
  width_num <- 8
  height_num <- 4  # Default setting as 8 countries
} else {
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# Print width and height for this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

data_climate <- data_climate %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))

data_climate_long <- data_climate_long %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))
ggplot() +
  # Bar chart for fin24C (now with fill mapped to "fin24C" so it enters the legend)
  geom_bar(data = data_climate, 
           aes(x = countrynewwb, y = fin24C, fill = "fin24C"),
           stat = "identity", position = "dodge", alpha = 0.5, color = "black") +
  
  # Bars for fin24D indicators
  geom_bar(data = data_climate_long, 
           aes(x = countrynewwb, y = value, fill = indicator),
           stat = "identity", position = "dodge", alpha = 0.7, color = "black") +
  
  # Unified manual fill scale
  scale_fill_manual(
    values = c(  # Grey bar
      "fin24D_1" = "#6AC9D0",   # Blue
      "fin24D_2" = "#B8CB33",
      "fin24C"   = "#cccccc"
    ),
    breaks = c("fin24D_1", "fin24D_2", "fin24C"),
    labels = c(
      "Suffered from damage to home or livestock",
      "Suffered from loss of income",
      "Experienced a natural disaster but did not lose income or assets"
    )
  ) +
  
  scale_y_continuous(
    labels = scales::comma_format(scale = 100),
    breaks = seq(0, 1, by = 0.2),
    limits = c(0, 1)
  ) +
  
  scale_x_discrete(labels = function(x) str_wrap(x, width = 15)) +
  
  theme(
    strip.placement = "outside",
    strip.text.x = element_text(size = 16, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    legend.key.size = unit(4, "mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16, hjust = 0),  # Set horizontal justification to 1 (left)
    axis.ticks.x = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.ticks.y = element_line(),
    plot.subtitle = element_text(size = 16, family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 16, family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 16, family = "Nunito Sans"),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 3, byrow = TRUE)) +
  # Add labels and titles
  labs(
    caption = "Source: Global Findex Database 2025\nNote: The economies included in this figure had 50 percent or more of adults saying they had been exposed to a natural disaster or extreme weather event in\nthe past three years.",
    title = "Half of all adults who experience a natural disaster faced loss of income or property damage\nhome",
    subtitle = "Adults who experienced a natural disaster or extreme weather event (%), 2024"
  )

# Export the image
ggsave(
  filename = file.path(folder_path, ("figure_sp2.2a.png")),
  width = width_num+2,
  height = height_num+3,
  device = 'png',
  dpi = 120
)
