
wage_payments <- data %>%
  filter(group == "gender") %>%
  filter(year == 2024) %>%
  filter(aggregate_level == "region_noq5") %>%
  select(countrynewwb, group2, ts_wg_any, ts_wg_dig) %>%
  # filter(!is.na(fin32)) %>%
  mutate("gap1" = ts_wg_dig,  
         "gap2" = ts_wg_any - ts_wg_dig,
         "total" = ts_wg_any) %>% 
  gather(group, value, gap1, gap2) %>%
  filter(!is.na(group), !is.na(value)) %>%  # filter NA values
  mutate(
    total = total * 100,
    value = value * 100,
    lab = ifelse(group == "gap1", round(total), NA)
  ) %>%
  filter(!is.na(total)) %>%
  mutate(
    countrynewwb = recode(countrynewwb,
                          "EAP (ex V5 countries)" = "East Asia and Pacific",
                          "ECA (ex V5 countries)" = "Europe and Central Asia",
                          "LAC (ex V5 countries)" = "Latin America and the Caribbean",
                          "MENA (ex V5 countries)" = "Middle East and North Africa",
                          "SAR (ex V5 countries)" = "South Asia",
                          "SSA (ex V5 countries)" = "Sub-Saharan Africa"
    )
  )


# Check the number of unique countries in countrynewwb
length_unique_countries <- wage_payments %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Check list of real data set country length
if (length_unique_countries < 8) {
  width_num <-8
  height_num <-4 # default setting as 8 countries
} else{
  # Every two country added ,width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

# Check about max value of y axis
max_val <- max(wage_payments$total, na.rm = TRUE) +15
if (max_val >92) {
  max_val <- 110
}

ggplot(wage_payments) +
  geom_bar(aes(x = factor(group2, levels = c("women", "men")),
               y = value,
               fill = factor(group, levels = c("gap2", "gap1"))),
           stat = "identity", 
           position = "stack",
           width = 0.75,
           color = "black") +
  scale_fill_manual(values = c("#15AFB7", "#F48E35"),
                    breaks = c("gap1", "gap2"),
                    labels = c("Into an account",
                               "In cash or some other way")) +
  scale_y_continuous(limits = c(0, 100),  # Set x-axis limits to range from 0 to 100
                     breaks = seq(0, 100, by = 20)) +
  scale_x_discrete(labels = function(x) str_to_title(x)) +
  facet_grid(.~ factor(countrynewwb), 
             scales = "free", 
             space = "free", 
             switch = "both", 
             labeller = label_wrap_gen(width = 18, multi_line = TRUE)) +
  
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(size = 16, family = "Nunito Sans", colour = "black", angle = 0, hjust = 0),
    strip.text.x = element_text(size = 16, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16, hjust = 1),
    axis.text.y.left = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_line(),
    plot.subtitle = element_text(size = 16, family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 18, family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 16, family = "Nunito Sans"),
    legend.text.align = 0,
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 2, byrow = TRUE)) +
  
  labs(
    subtitle = "Adults receiving a wage payment in the past year (%), 2024",
    title = "Though women in low- and middle-income economies on average are as likely as men to receive wage\npayments digitally, wide disparities exist in some regions",
    caption = "Source: Global Findex Database 2025\nNote: Due to lack of data averages exclude Algeria, China, Iran, Libya, Mauritius, Russia, and Ukraine."
  )

# Export the plot
ggsave(
  filename = file.path(folder_path, sprintf("3.3.11.png")),
  width = width_num+2,
  height = height_num+2,
  device = 'eps',
  dpi = 120
)

ggsave(
  filename = file.path(folder_path, sprintf("3.3.11.eps")),
  width = width_num+2,
  height = height_num+2,
  device = 'eps',
  dpi = 120
)

