library(stringr)
library(scales)


df3 <- TS %>% filter(i24 == 1 & regionwb24_hi != "High income" & countrynewwb != "India") %>%
  summarize(ts_account = weighted.mean(ts_account, wgt_globalgfii),
            ts_dormant_FI = weighted.mean(ts_dormant_FI, wgt_globalgfii)) %>%
  mutate(countrynewwb = "LMIC (excluding India)")

active_acc <- data %>%
  filter(i24 == 1) %>%
  filter(countrynewwb %in% c("LMIC (excluding India)", "India")) %>%
  select(countrynewwb, ts_account, ts_dormant_FI) %>%
  rbind(df3) %>%
  filter(!is.na(ts_account)) %>%
  mutate(
    gap1 = ts_account - ts_dormant_FI,
    gap2 = ts_dormant_FI,
    total = ts_account
  ) %>%
  gather(group, value, gap1, gap2) %>%
  filter(!is.na(group), !is.na(value)) %>%
  mutate(
    total = total * 100,
    value = value * 100,
    lab = ifelse(group == "gap1", round(total), NA)
  ) %>%
  filter(!is.na(total)) %>%
  mutate(
    countrynewwb = recode(countrynewwb,
                          "LMIC (excluding India)" = "Low- and middle-income economies (excluding India)"))

length_unique_countries <- active_acc %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Calculate width and height based on unique countries
if (length_unique_countries < 8) {
  width_num <- 8
  height_num <- 4
} else {
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

# Check max value for y-axis
max_val <- max(active_acc$total, na.rm = TRUE) + 15
if (max_val > 92) {
  max_val <- 110
}

# Create the plot
ggplot(active_acc) +
  geom_bar(
    aes(
      y = factor(countrynewwb),
      x = value,
      fill = factor(group, levels = c("gap2", "gap1"))
    ),
    stat = "identity",
    position = "stack",
    width = 0.75,
    color = "black"
  ) +
  scale_fill_manual(
    values = c("gap1" = "#0F72BC", "gap2" = "#B8CB33"),
    breaks = c("gap1", "gap2"),
    labels = c(
      "Active account",
      "Inactive account"
    )
  ) +
  scale_x_continuous(
    limits = c(0, max_val),
    breaks = seq(0, max_val, by = 20)
  ) +
  scale_y_discrete(labels = wrap_format(32))+
  theme(
    strip.placement = "outside",
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = "left",
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(
      family = "Nunito Sans",
      color = "black",
      size = 16
    ),
    axis.text.y = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 16,
      hjust = 0),
    axis.ticks.y = element_blank(),
    axis.ticks.x = element_line(color = "black"),
    plot.subtitle = element_text(size = 16, family = "Nunito Sans"),
    plot.title = element_text(
      hjust = 0,
      size = 16,
      family = "Nunito Sans",
      face = "bold"
    ),
    plot.title.position = "plot",
    legend.text = element_text(size = 16, family = "Nunito Sans"),
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 1, byrow = TRUE)) +
  labs(
    caption = "Source: Global Findex Database 2025",
    subtitle = "Adults with an account (%), 2024",
    title = "In India, 16 percent of account owners have an inactive account, as compared to 4 percent in \nother low- and middle-income economies"
  )

# Save the plot
ggsave(
  filename = file.path(folder_path, sprintf("3.3.14.png")),
  width = width_num,
  height = height_num-1,
  device = 'png',
  dpi = 120
)

ggsave(
  filename = file.path(folder_path, sprintf("3.3.14.eps")),
  width = width_num,
  height = height_num-1,
  device = 'eps',
  dpi = 120
)
