
install.packages("patchwork")
library(patchwork)

# df <- read_csv("\\\\wbntpcifs\\Gallop\\Anh\\payments_data.csv")

cash_acc <- TS %>%
  mutate(acc_cashpay = case_when(dev24 == 1 & ts_account == 1 & (ts_g2p_cashonly == 1 | ts_fin_wgpriv_cashonly == 1) ~ 1,
                                dev24 == 1 ~ 0,
                                TRUE ~ NA),
         cash_wg_g2p = case_when(dev24 == 1 & (ts_g2p_cashonly == 1 | ts_fin_wgpriv_cashonly == 1) ~ 1,
                                 dev24 == 1 ~ 0,
                                 TRUE ~ NA)) %>%
  filter(dev24 == 1 & regionwb24_hi != "High income") %>%
  group_by(regionwb24_hi) %>%
  summarise(acc_cashpay = weighted.mean(acc_cashpay, wgt_globalgfii),
            cash_wg_g2p = weighted.mean(cash_wg_g2p, wgt_globalgfii)) %>%
  select(regionwb24_hi, acc_cashpay, cash_wg_g2p) %>%
  filter(!is.na(cash_wg_g2p)) %>%
  mutate(
    gap1 = acc_cashpay,
    gap2 = cash_wg_g2p - acc_cashpay,
    total = cash_wg_g2p
  ) %>%
  gather(group, value, gap1, gap2) %>%
  filter(!is.na(group), !is.na(value)) %>%
  mutate(
    total = total * 100,
    value = value * 100,
    lab = ifelse(group == "gap1", round(total), NA)
  ) %>%
  filter(!is.na(total)) %>%
  mutate(
    regionwb24_hi = recode(regionwb24_hi,
                          "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                          "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                          "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                          "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                          "South Asia (excluding high income)" = "South Asia",
                          "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"
    )
  )

# Check the number of unique countries
length_unique_countries <- cash_acc %>%
  summarise(unique_countries = n_distinct(regionwb24_hi)) %>%
  pull(unique_countries)

# Calculate width and height based on unique countries
if (length_unique_countries < 8) {
  width_num <- 8
  height_num <- 4
} else {
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

# Check max value for y-axis
max_val <- max(cash_acc$total, na.rm = TRUE) + 15
if (max_val > 92) {
  max_val <- 110
}

# Create the plot
plot1 <- ggplot(cash_acc) +
  geom_bar(
    aes(
      x = regionwb24_hi,
      y = value,
      fill = factor(group, levels = c("gap2", "gap1"))
    ),
    stat = "identity",
    position = "stack",
    width = 0.75,
    color = "black"
  ) +
  scale_fill_manual(
    values = c("gap1" = "#5696D0", "gap2" = "#F48E35"),
    breaks = c("gap1", "gap2"),
    labels = c(
      "Have an account",
      "Do not have an account"
    )
  ) +
  scale_y_continuous(
    limits = c(0, 30),
    breaks = seq(0, 30, by = 10)
  ) +
  scale_x_discrete(labels = wrap_format(15))+
  theme(
    strip.placement = "outside",
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = "center",
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(
      family = "Nunito Sans",
      color = "black",
      size = 20
    ),
    axis.text.y = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 20,
      hjust = 0),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_line(color = "black"),
    plot.subtitle = element_text(size = 20, family = "Nunito Sans"),
    plot.title = element_text(
      hjust = 0,
      size = 20,
      family = "Nunito Sans",
      face = "bold"
    ),
    plot.title.position = "plot",
    legend.text = element_text(size = 20, family = "Nunito Sans"),
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0, size = 16, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 2, byrow = TRUE)) +
  labs(
    caption = NULL,
    subtitle = "Adults who received a government or private \nsector wage payment in cash (%), 2024",
    title = NULL
  )

### second panel
cash_phone <- TS %>%
  mutate(ub_cashpay = case_when(dev24 == 1 & ts_account == 0 & (ts_g2p_cashonly == 1 | ts_fin_wgpriv_cashonly == 1) ~ 1,
                                 dev24 == 1 ~ 0,
                                 TRUE ~ NA),
         phone_cashpay_ub = case_when(dev24 == 1 & ts_account == 0 & con1_all == 1 & (ts_g2p_cashonly == 1 | ts_fin_wgpriv_cashonly == 1) ~ 1,
                                       dev24 == 1 ~ 0,
                                       TRUE ~ NA),
         bphone_cashpay_ub = case_when(dev24 == 1 & ts_account == 0 & con9_all_basic == 1 & (ts_g2p_cashonly == 1 | ts_fin_wgpriv_cashonly == 1) ~ 1,
                                 dev24 == 1 ~ 0,
                                 TRUE ~ NA),
         fphone_cashpay_ub = case_when(dev24 == 1 & ts_account == 0 & con10_all == 1 & (ts_g2p_cashonly == 1 | ts_fin_wgpriv_cashonly == 1) ~ 1,
                                 dev24 == 1 ~ 0,
                                 TRUE ~ NA),
         sp_cashpay_ub = case_when(dev24 == 1 & ts_account == 0 & con9_all_smart == 1 & (ts_g2p_cashonly == 1 | ts_fin_wgpriv_cashonly == 1) ~ 1,
                                 dev24 == 1 ~ 0,
                                 TRUE ~ NA),) %>%
  filter(dev24 == 1 & regionwb24_hi != "High income") %>%
  group_by(regionwb24_hi) %>%
  summarise(phone_cashpay_ub = weighted.mean(phone_cashpay_ub, wgt_globalgfii),
            ub_cashpay = weighted.mean(ub_cashpay, wgt_globalgfii),
            bphone_cashpay_ub = weighted.mean(bphone_cashpay_ub, wgt_globalgfii),
            fphone_cashpay_ub = weighted.mean(fphone_cashpay_ub, wgt_globalgfii),
            sp_cashpay_ub = weighted.mean(sp_cashpay_ub, wgt_globalgfii)) %>%
  
  select(regionwb24_hi, ub_cashpay, phone_cashpay_ub, bphone_cashpay_ub, fphone_cashpay_ub, sp_cashpay_ub) %>%
  filter(!is.na(ub_cashpay)) %>%
  mutate(
    gap1 = bphone_cashpay_ub - fphone_cashpay_ub,
    gap2 = fphone_cashpay_ub,
    gap3 = sp_cashpay_ub,
    gap4 =ub_cashpay - phone_cashpay_ub,
    total = ub_cashpay
  ) %>%
  gather(group, value, gap1, gap2, gap3, gap4) %>%
  filter(!is.na(group), !is.na(value)) %>%
  mutate(
    total = total * 100,
    value = value * 100,
    lab = ifelse(group == "gap1", round(total), NA)
  ) %>%
  filter(!is.na(total)) %>%
  mutate(
    regionwb24_hi = recode(regionwb24_hi,
                           "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                           "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                           "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                           "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                           "South Asia (excluding high income)" = "South Asia",
                           "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"
    )
  )

max_val <- max(cash_phone$total, na.rm = TRUE) + 15
if (max_val > 92) {
  max_val <- 110
}


plot2 <- ggplot(cash_phone) +
  geom_bar(
    aes(
      x = regionwb24_hi, # Y-axis: country names
      y = value,
      fill = factor(group, levels = c("gap4","gap3", "gap2", "gap1"))
    ),
    stat = "identity",
    position = "stack",
    width = 0.75,
    color = "black"
  ) +
  scale_fill_manual(
    values = c("gap1" = "#5696D0", "gap2" = "#8066AB", "gap3" = "#D12891", "gap4" = "#cccccc"),
    breaks = c("gap1", "gap2", "gap3", "gap4"),
    labels = c(
      "Basic phone",
      "Feature phone",
      "Smartphone",
      "No phone"
    )
  ) +
  scale_y_continuous(
    limits = c(0, 30),
    breaks = seq(0, 30, by = 10)
  ) +
  scale_x_discrete(labels = wrap_format(15))+
  theme(
    strip.placement = "outside",
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = "center",
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(
      family = "Nunito Sans",
      color = "black",
      size = 20
    ),
    axis.text.y = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 20,
      hjust = 0),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_line(color = "black"),
    plot.subtitle = element_text(size = 20, family = "Nunito Sans"),
    plot.title = element_text(
      hjust = 0,
      size = 20,
      family = "Nunito Sans",
      face = "bold"
    ),
    plot.title.position = "plot",
    legend.text = element_text(size = 20, family = "Nunito Sans"),
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0, size = 16, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 3, byrow = TRUE)) +
  labs(
    caption = NULL,
    subtitle = "Unbanked adults who received a government or \nprivate sector wage payment in cash (%), 2024",
    title = NULL
  )

final_plot <- plot1 + plot2 +
  plot_layout(ncol = 2)

# Add only a shared title and caption
final_plot <- final_plot +
  plot_annotation(
    title = "Opportunities remain to digitalize government or wage payments to drive financial inclusion",
    caption = "Source: Global Findex Database 2025\nNote: Due to lack of data averages exclude Algeria, China, Iran, Libya, Mauritius, Russia, and Ukraine.",
    theme = theme(
      plot.title = element_text(
        size = 22, face = "bold", family = "Nunito Sans", hjust = 0
      ),
      plot.caption = element_text(
        size = 16, family = "Nunito Sans", hjust = 0
      )
    )
  )

# Print the final plot
final_plot

# Save the plot
ggsave(
  filename = file.path(folder_path, sprintf("3.3.17.png")),
  width = width_num+14,
  height = height_num+5,
  device = 'eps',
  dpi = 120
)

ggsave(
  filename = file.path(folder_path, sprintf("3.3.17.eps")),
  width = width_num+10,
  height = height_num+5,
  device = 'eps',
  dpi = 120
)
