

data <- data %>%
  mutate(deposit_fi = fin5_fi_w + fin5_fi_m + fin5_fi_lm + fin5_fi_n,
         withdraw_fi = fin6_fi_w + fin6_fi_m + fin6_fi_lm + fin6_fi_n)
  
inflows_outflows <- data %>%
  filter(group == "all") %>%
  filter(year %in% c(2024)) %>%
  filter(countrynewwb %in% c_region) %>%
  select(countrynewwb, year, fin5_fi_w, fin5_fi_m, fin5_fi_lm, fin5_fi_n,
         fin6_fi_w, fin6_fi_m, fin6_fi_lm, fin6_fi_n)


# Reshape data to long format for ggplot
inflows_outflows <- inflows_outflows %>%
  pivot_longer(cols = starts_with("fin5_fi") | starts_with("fin6_fi"),
               names_to = c("type", "category"),
               names_pattern = "(.*)_(.*)",
               values_to = "value") %>%
  mutate(type = factor(type, levels = c("fin5_fi", "fin6_fi")),
         category = factor(category, levels = c("w", "m", "lm", "n"), 
                           labels = c("Weekly", "Monthly", "Less than once a month", "Never")))

# Normalize the data to 100% by country and type (data_purchase or internet_access)
inflows_outflows_long <- inflows_outflows %>%
  group_by(countrynewwb, type) %>%
  # Ensure all categories (w, m, lm, n) are included for each country
  complete(category = factor(c("Weekly", "Monthly", "Less than once a month", "Never"), 
                             levels = c("Weekly", "Monthly", "Less than once a month", "Never"))) %>%
  filter(!is.na(value)) %>%
  # Normalize by the sum of the values for each country and type
  mutate(percentage = value / sum(value, na.rm = TRUE) * 100) %>%
  ungroup()

# Check the number of unique countries in countrynewwb
length_unique_countries <- inflows_outflows_long %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

if (length_unique_countries < 8) {
  width_num <-8
  height_num <-4 # default setting as 8 countries
} else{
  # Every two country added ,width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 3) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 3)
}

# print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

unique_countries_list <- inflows_outflows %>%
  distinct(countrynewwb) %>%
  pull(countrynewwb)

deposit_label_data <- data %>%
  filter(group == "all") %>%
  filter(year %in% c(2024)) %>%
  filter(countrynewwb %in% unique_countries_list) %>%
  select(countrynewwb, deposit_fi) %>%
  rename(total = deposit_fi)

withdraw_label_data <- data %>%
  filter(group == "all") %>%
  filter(year %in% c(2024)) %>%
  filter(countrynewwb %in% unique_countries_list) %>%
  select(countrynewwb, withdraw_fi) %>%
  rename(total = withdraw_fi)

# Merge the total data for Purchase Data and Internet Access with the long data
inflows_outflows_with_labels <- inflows_outflows_long %>%
  left_join(deposit_label_data, by = "countrynewwb") %>%
  left_join(withdraw_label_data, by = "countrynewwb", suffix = c("_deposit", "_withdraw")) %>%
  mutate(
    label = case_when(
      type == "fin5_fi" ~ total_deposit,    
      type == "fin6_fi" ~ total_withdraw,
      TRUE ~ NA_real_
    )
  )%>%
  drop_na(label) %>%
  drop_na(total_deposit) %>%
  drop_na(total_withdraw)

# Recode the abbreviations directly in the data
inflows_outflows_with_labels$countrynewwb <- recode(inflows_outflows_with_labels$countrynewwb,
                                             "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                                             "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                                             "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                                             "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                                             "South Asia (excluding high income)" = "South Asia",
                                             "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa")

ggplot(inflows_outflows_with_labels) +
  # First geom_bar() for plotting the bars
  geom_bar(aes(x = factor(type), 
               y = percentage, 
               fill = factor(category, levels = c("Never", "Less than once a month", "Monthly", "Weekly"))),
           stat = "identity", 
           position = "stack", 
           width = 0.75,
           color = "black") +
  
  # Custom colors for the categories, reverse the order in the legend
  scale_fill_manual(values = c("Weekly" = "#0F72BC", 
                               "Monthly" = "#5696D0", 
                               "Less than once a month" = "#B2D6F7", 
                               "Never" = "#C2C0C0"),
                    breaks = c("Weekly", "Monthly", "Less than once a month", "Never"),  # Correct legend order with Daily first
                    labels = c("Weekly", "Monthly", "Less than once a month", "Never")) +  # Correct legend labels
  
  # Facet by country
  facet_grid(. ~ factor(countrynewwb), 
             scales = "free", 
             space = "free", 
             switch = "both", 
             labeller = label_wrap_gen(width = 18, multi_line = TRUE)) +
  
  # Labels and title
  labs(x = "Type", y = "Percentage", fill = "Category",
       title = "100% Normalized Stacked Bar Chart for Data Purchase and Internet Access") +
  
  scale_x_discrete(
    labels = function(x) {
      # Map the old labels to the new names and wrap the text
      x <- recode(x, 
                  "fin5_fi" = "Received or deposited money", 
                  "fin6_fi" = "Sent or withdrew money")
      str_wrap(x, width = 10) 
    }
  ) +
  
  theme(
    # legend.position = "none",
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0),
    strip.text.y = element_text(size = 20, family = "Nunito Sans"),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border=element_blank(),
    legend.title = element_blank(),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text( 
      family = "Nunito Sans",
      color = "black",
      hjust = 0.5,
      vjust = 0.5,
      size = 18),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 18),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_blank(),
    # axis.ticks.y = element_blank(),
    plot.subtitle = element_text(size = 20,
                                 family = "Nunito Sans"),
    plot.title = element_text(hjust = 0,
                              size = 20,
                              family = "Nunito Sans",
                              face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(#hjust = 0,
      size = 18,
      family = "Nunito Sans"),
    # legend.text.align = 0,
    legend.position ="bottom",
    legend.justification='center',
    legend.direction = "horizontal",
    strip.text.x = element_text(family = "Nunito Sans",
                                color = "black",
                                size = 18),
    plot.caption = element_text(hjust = 0, size = 14, family = "Nunito Sans"),
    plot.caption.position =  "plot") +
  guides(fill = guide_legend(nrow = 1, byrow = TRUE)) +
  labs(caption = "Source: Global Findex Database 2025",
       subtitle = "Adults who own a bank or similar financial institution accounts, standardized to 100%, 2024", 
       title = "For most bank account owners, inflows and outflows occur at roughly even intervals ")

ggsave(
  filename = file.path(folder_path, ("3.3.18.png")),
  width = width_num + 5,
  height = height_num+3,
  units = "in", 
  device = 'png',
  dpi = 120
)

ggsave(
  filename = file.path(folder_path, ("3.3.18.eps")),
  width = width_num + 5,
  height = height_num+3,
  units = "in", 
  device = 'eps',
  dpi = 120
)
