


mpay_data <- data %>% 
  filter(year == 2024, countrynewwb %in% c_region) %>%
  select(countrynewwb, fin25E_4_cash, fin25E_4_exp, fin25E_4_notrust,
         fin25E_4_usedtocash, fin25E_4_other) 

# Create the mapping for labels
indicator_mapping <- data.frame(
  indicator = c("fin25E_4_cash", "fin25E_4_exp", "fin25E_4_notrust", "fin25E_4_usedtocash", "fin25E_4_other"),
  mpay_label = c(
    "Merchant only accepts cash",
    "Paying with a card or phone is more expensive",
    "Don't trust payments using card or phone",
    "Used to paying with cash",
    "Other reasons"
  )
)

# Reshape data to long format for fin14a-g
mpay_data_long <- mpay_data %>%
  pivot_longer(
    cols = starts_with("fin25"), 
    names_to = "indicator", 
    values_to = "value"
  ) %>%
  left_join(indicator_mapping, by = "indicator")  # Join with mapping

mpay_data_long <- mpay_data_long %>%
  mutate(value = value * 100) %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))


custom_order <- c(
  "Used to paying with cash",
  "Merchant only accepts cash",
  "Don't trust payments using card or phone",
  "Paying with a card or phone is more expensive",
  "Other reasons"
)

# Apply the factor levels in that custom order
mpay_data_long$mpay_label <- factor(mpay_data_long$mpay_label, levels = custom_order)

# Check for missing values
sum(is.na(mpay_data_long$value))  # Ensure no NAs are present in the value column
mpay_data_long$value[is.na(mpay_data_long$value)] <- 0  # Replace NAs with 0

# Find the min and max values of 'Value' for proper scaling
min_value <- min(mpay_data_long$value, na.rm = TRUE)
max_value <- max(mpay_data_long$value, na.rm = TRUE)

# Debug: Print min and max values to check
print(paste("Min value:", min_value))
print(paste("Max value:", max_value))


ggplot(mpay_data_long, aes(x = factor(mpay_label, levels = custom_order),  y = fct_rev(countrynewwb),  
                                                      fill = value)) +
  geom_tile(color = "black") +
  scale_fill_gradient2(low = "#E6E6E6", mid = "#D8E157", high ="#B8CB33",
                       midpoint = (max_value + min_value) / 2,
                       limits = c(min_value, max_value),
                       name = "Value (%)",
                       labels = label_percent(scale = 1)) +  # Format the legend as percentages
  geom_text(aes(label = paste0(round(value), "%")), color = "black", size = 5.5, check_overlap = TRUE) +
  facet_wrap(~ mpay_label,
             scales = "free_x",
             nrow = 1,
             labeller = label_wrap_gen(width = 14)) +
  
  # Use str_wrap to wrap the noMM_label for better visualization
  labs(caption = "Soure: Global Findex Database 2025",
       title = " The habit of paying in cash is the most common reason why people do not pay merchants digitally every region",
       subtitle = "Adults who did not make a digital payment for in-store purchases in the past 12 months (%), 2024") +
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0),
    strip.text.x = element_text(size = 16, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    legend.text = element_text(hjust = 0, size = 12, family = "Nunito Sans"),  # Corrected the legend text definition
    legend.key.size = unit(12, "mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16, hjust = 0),  # Adjust y-axis text size
    axis.ticks.y = element_blank(),
    axis.text.x = element_blank(),
    axis.ticks.x = element_blank(),
    plot.subtitle = element_text(size = 16, family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 16, family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans"),
    plot.caption.position = "plot"
  )

ggsave(
  filename = file.path(folder_path, sprintf("3.3.19.png")),
  width = width_num+1.5,
  height = height_num+2,
  device = 'png',
  dpi = 120
)

ggsave(
  filename = file.path(folder_path, sprintf("3.3.19.eps")),
  width = width_num+1.5,
  height = height_num+2,
  device = 'eps',
  dpi = 120
)

