


library(ggplot2)
library(dplyr)
library(tidyr)
library(forcats)
library(stringr)


digpay_data <- data %>%
  filter(group %in% c("age_cat", "income", "urbanicity")) %>%
  filter(year == 2024) %>%
  filter(countrynewwb == "LMIC") %>%
  select(countrynewwb, year, group, group2, ts_account, ts_digpay_imputed) %>%
  mutate(group2 = recode (group2,
                          "ages 15-24" = "Ages 15-24",
                          "age 25+" = "Age 25+",
                          "poorest 40%" = "Poorest 40%",
                          "richest 60%" = "Wealthiest 60%",
                          "rural" = "Rural",
                          "urban" = "Urban")) %>%
  group_by(group, group2) %>%
  summarise(
    ts_account = sum(ts_account, na.rm = TRUE),
    ts_digpay_imputed = sum(ts_digpay_imputed, na.rm = TRUE),
    .groups = "drop"
  ) %>%
  mutate(
    gap1 = ts_digpay_imputed,
    gap2 = ts_account - ts_digpay_imputed,
    total = ts_account
  ) %>%
  gather(cat, value, gap1, gap2) %>%
  filter(!is.na(cat), !is.na(value), !is.na(group2)) %>%
  mutate(
    total = total * 100,
    value = value * 100,
    lab = ifelse(cat == "gap1", round(total), NA)
  ) %>%
  filter(value != 0, !is.na(total))

digpay_data$group <- factor(
  digpay_data$group,
  levels = c("income", "urbanicity", "age_cat")
)

ggplot(digpay_data) +
  geom_bar(
    aes(
      x = factor(group2, levels = c("Poorest 40%", "Wealthiest 60%", "Rural", "Urban", "Ages 15-24", "Age 25+")),
      y = value,
      fill = factor(cat, levels = c("gap2", "gap1"))
    ),
    stat = "identity",
    position = "stack",
    width = 0.7,
    color = "black"
  ) +
  scale_fill_manual(
    values = c("gap1" = "#15AFB7", "gap2" = "#c2C0c0"),
    breaks = c("gap1", "gap2"),
    labels = c("Made or received a digital payment",
               "Did not make or receive a digital payment")
  ) +
  scale_y_continuous(
    limits = c(0, 100),
    breaks = seq(0, 100, by = 20)
  ) +
  scale_x_discrete(labels = wrap_format(20)) +
  facet_grid(
    . ~ group,
    scales = "free",
    space = "free",
    switch = "both",
    labeller = labeller(
      group = c(
        "income" = "Income",
        "urbanicity" = "Rural/Urban",
        "age_cat" = "Age"
      )
    )
  ) +
  theme(
    strip.placement = "outside",
    strip.text.x = element_text(size = 20, family = "Nunito Sans", colour = "black", angle = 0), 
    strip.text.y = element_text(size = 20, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 20),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 20),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_line(color = "black"),
    plot.subtitle = element_text(size = 20, family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 20, family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 20, family = "Nunito Sans"),
    legend.text.align = 0,
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0, size = 16, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 2, byrow = TRUE)) +
  labs(
    caption = "Source: Global Findex Database 2025\nNote: In Algeria, China, Iran, Libya, Mauritius, and Ukraine, an abridged questionnaire was administered by phone, and did not include any \nof the questions on receiving payments.  For these six countries, adults who make a digital payment or access their account using a card\nor phone are identified as having made or received a digital payment. ",
    subtitle = "Adults with an account (%), 2024",
    title = "Women, poor, and rural account ownerss are less likely to use digital payments than men, wealthier,\nand urban account owners"
  )


ggsave(
  filename = file.path(folder_path, "3.3.4.png"),
  width = width_num+3,
  height = height_num+3,
  device = 'png',
  dpi = 120
)

ggsave(
  filename = file.path(folder_path, "3.3.4.eps"),
  width = width_num+3,
  height = height_num+3,
  device = 'eps',
  dpi = 120
)
