library(data.table)
library(dplyr)
library(stringr)
library(tidyr)
library(ggplot2)
library(forcats)
library(scales)

# Optional: font setup
# library(showtext)
# font_add_google("Nunito Sans", "Nunito Sans")
# showtext_auto()

# Read data (you can uncomment and adjust this line)
# TS <- fread("\\\\wbntpcifs\\Gallop\\Analysis, other docs, by year\\2024\\Analysis\\Findex_2024_individual.csv")

# Remove countries with >88% account ownership
fi_bar <- TS %>% 
  filter(i24 == 1) %>%
  filter(countrynewwb == "India") %>%
  select(countrynewwb, wgt_globalgfii, starts_with("fin11")) %>%
  group_by(countrynewwb) %>%
  summarize(across(
    where(is.numeric) & !any_of(c("wgt_globalgfii")),
    ~ {
      mean_value <- weighted.mean(.x, wgt_globalgfii, na.rm = TRUE)
      if (is.nan(mean_value)) NA else mean_value
    }), .groups = 'drop') 

# Filter data
unbanked_reason_data_filtered <- fi_bar %>%
  select(countrynewwb, fin11A_all_ub, fin11B_ub, fin11C_ub,
         fin11D_ub, fin11E_ub, fin11F_ub) %>%
  filter(!is.na(fin11A_all_ub))

# Label mapping
indicator_mapping <- data.frame(
  indicator = c("fin11A_all_ub", "fin11B_ub", "fin11C_ub",
                "fin11D_ub", "fin11E_ub","fin11F_ub"),
  unbanked_label = c(
    "Financial Institutions\ntoo far",
    "Financial service\nfees too expensive",
    "Lack of\ndocumentation",
    "Not enough\nmoney",
    "Family member\nhas account",
    "Do not trust\ninstitutions"
  )
)

# Reshape and join with labels
unbanked_reason_data_long <- unbanked_reason_data_filtered %>%
  pivot_longer(
    cols = starts_with("fin11"), 
    names_to = "indicator", 
    values_to = "value"
  ) %>%
  left_join(indicator_mapping, by = "indicator") %>%
  mutate(
    value = value * 100,
    unbanked_label = factor(unbanked_label, levels = c(
      "Not enough\nmoney",
      "Financial service\nfees too expensive",
      "Family member\nhas account",
      "Financial Institutions\ntoo far",
      "Do not trust\ninstitutions",
      "Lack of\ndocumentation"
    ))
  )

# Handle NAs
unbanked_reason_data_long$value[is.na(unbanked_reason_data_long$value)] <- 0

# Get color scale bounds
min_value <- min(unbanked_reason_data_long$value, na.rm = TRUE)
max_value <- max(unbanked_reason_data_long$value, na.rm = TRUE)

# Plot
heatmap_plot <- ggplot(unbanked_reason_data_long, aes(x = unbanked_label, y = fct_rev(countrynewwb), fill = value)) +
  geom_tile(color = "black") +
  scale_fill_gradient2(
    low = "#C2C0C0", mid = "#E9867D", high = "#D3172A",
    midpoint = (max_value + min_value) / 2,
    limits = c(min_value, max_value),
    name = "Value (%)",
    labels = label_percent(scale = 1)
  ) +
  geom_text(aes(label = paste0(round(value), "%")), color = "black", size = 5) +
  scale_x_discrete(position = "top") +
  labs(
    title = "Lack of money is the main barrier to account ownership for most unbanked adults",
    subtitle = "Adults with no account (%), 2024\n",
    caption = "Source: Global Findex Database 2025"
  ) +
  theme(
    strip.placement = "outside",
    strip.text.x = element_text(size = 16, family = "Nunito Sans", colour = "black"),
    panel.background = element_blank(),
    panel.grid = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    legend.text = element_text(hjust = 0, size = 12, family = "Nunito Sans"),
    legend.key.size = unit(8, "mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16, hjust = 0),
    axis.ticks.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 14, angle = 0, hjust = 0.5),
    axis.ticks.x = element_blank(),
    plot.subtitle = element_text(size = 16, family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 16, family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans"),
    plot.caption.position = "plot"
  )

# Display the plot
heatmap_plot

# Save the plot
ggsave(
  filename = file.path(folder_path, "2.2.4.png"),
  plot = heatmap_plot,
  width = 12,
  height = 6,
  units = "in",
  device = 'png',
  dpi = 120
)
