library(data.table)
library(dplyr)
library(tidyr)
library(ggplot2)
library(showtext)

# Optional font loading
# font_add_google("Nunito Sans", "nunito")
# showtext_auto()

# Load and prepare the data
phone <- TS %>%
  filter(dev24 == 1 & regionwb24_hi == "Sub-Saharan Africa (excluding high income)" & African_Union != "AU_North" & ts_account == 0) %>%
  filter(!countrynewwb %in% c("Chad", "Liberia")) %>%
  group_by(African_Union) %>%
  summarize(con1_all = weighted.mean(con1_all, wgt_globalgfii, na.rm = T),
            # con9_all_smart = weighted.mean(con9_all_smart, wgt_globalgfii, na.rm = T),
            id_any = weighted.mean(id_any, wgt_globalgfii, na.rm = T),
            con11_all = weighted.mean(con11_all, wgt_globalgfii, na.rm = T)) %>%
  pivot_longer(cols = c(con1_all, id_any, con11_all), values_to = "main", names_to = "group") %>%
  mutate(others = 1 - main) %>%
  # fread("\\\\wbntpcifs\\Gallop\\Analysis, other docs, by year\\2024\\Output\\Donut_Data\\TS_UNBANKED_AU_dpi.csv") %>%
  pivot_longer(cols = c("main", "others"), names_to = "type") %>%
  mutate(
    value = value * 100,
    type_label = fct_rev(recode(type,
                                "main" = "Has/Owns",
                                "others" = "Does not have/own"
    ))
  ) %>%
  arrange(African_Union, group, type) %>%
  filter(African_Union != "AU_North") %>%
  group_by(African_Union, group) %>%
  mutate(
    ymin = c(0, cumsum(value)[-length(value)]),
    ymax = cumsum(value),
    labelPosition = 100 - ((ymin + ymax) / 2)
  ) %>%
  mutate(
    group_lab = case_when(
      group == "con1_all" ~ "Owns a\nmobile phone",
      # group == "con9_all_smart" ~ "Owns a\nsmartphone",
      group == "id_any" ~ "Has ID",
      group == "con11_all" ~ "Has SIM registered \nin own name",
      TRUE ~ group
    )
  ) %>%
  filter(!group %in% c("fin46_all", "ts_g2p_cashonly")) %>%
  mutate(
    group_lab = factor(group_lab, levels = c(
      "Owns a\nmobile phone",
      "Has ID",
      "Has SIM registered \nin own name"
      # "Owns a\nsmartphone"
    )),
    African_Union = recode(African_Union,
                           "AU_Central" = "Central Africa",
                           "AU_East" = "East Africa",
                           "AU_Southern" = "Southern Africa",
                           "AU_West" = "West Africa"
    )
  )

# Create the plot
p <- ggplot(phone, aes(x = 2, y = value, fill = type_label)) +
  geom_bar(stat = "identity", width = 1, color = "black", size = 1.5) +
  geom_text(
    data = subset(phone, type == "main"),
    aes(x = 3, y = labelPosition, label = round(value)),
    color = "black", size = 25, family = "nunito"
  ) +
  coord_polar("y", start = 0, direction = -1) +
  xlim(c(0.5, 3.3)) +
  facet_grid(African_Union ~ group_lab, switch = "y") +
  scale_fill_manual(
    values = c(
      "Does not have/own" = "#0f72bc",  # Blue
      "Has/Owns" = "#d12891"            # Pink
    ),
    labels = c(
      "Has/Owns" = "Owns a mobile phone, has ID, has SIM registered in own name, owns a smartphone",
      "Does not have/own" = "Does not own a mobile phone, does not have ID, does not have SIM registered in own name, does not\nown a smartphone"
    ), 
    name = NULL
  ) +
  guides(fill = guide_legend(reverse = FALSE)) +
  theme_void() +
  theme(
    legend.position = "bottom",
    legend.direction = "vertical",
    legend.box = "vertical",
    legend.text = element_text(size = 66, family = "nunito"),
    legend.spacing.y = unit(2, "cm"),
    legend.key.width = unit(3, "cm"),      # <--- Wider color box
    
    strip.text.x = element_text(size = 66, family = "nunito"),
    strip.text.y.left = element_text(size = 66, family = "nunito", hjust = 0),
    strip.background = element_blank(),
    panel.spacing = unit(1, "lines"),
    plot.title.position = "panel",
    plot.title = element_text(hjust = 0, size = 78, family = "nunito", face = "bold"),
    plot.subtitle = element_text(hjust = 0, size = 74, family = "nunito"),
    plot.caption = element_text(size = 68, hjust = -0.3, family = "nunito"),
    text = element_text(family = "nunito")
  ) +
  labs(
    title = "Unbanked adults in Sub-Saharan Africa need the necessary digital enablers\nfor mobile money account ownership ",
    subtitle = "Adults with no account (%), 2024\n",
    caption = "\n\nSource: Global Findex Database 2025"
  )

p

# Save the plot
ggsave(
  # filename = "\\\\wbntpcifs\\gallop\\Alexandra\\test_donut.png",
  filename = file.path(folder_path, "2.2.6.png"),
  plot = p,
  width = 49,
  height = 49,
  units = "in",
  device = 'png',
  dpi = 120
)
