library(dplyr)
library(tidyr)
library(ggplot2)
library(scales)
library(showtext)

# Font setup (optional)
# font_add_google("Nunito Sans", "Nunito Sans")
# showtext_auto()

# Define region list and display labels
c_list_agg <- c(
  "East Asia & Pacific (excluding high income)", 
  "Europe & Central Asia (excluding high income)",
  "High income",
  "Latin America & Caribbean (excluding high income)", 
  "Middle East & North Africa (excluding high income)", 
  "South Asia (excluding high income)", 
  "Sub-Saharan Africa (excluding high income)"
)

legend_labels <- c(
  "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
  "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
  "High income" = "High income",
  "Latin America & Caribbean (excluding high income)" = "Latin America and\nthe Caribbean", 
  "Middle East & North Africa (excluding high income)" = "Middle East and North Africa", 
  "South Asia (excluding high income)" = "South Asia", 
  "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"
)

# Compute smart shade value for High income region from TS
hi_smart_value <- TS %>%
  mutate(unbanked_sp_all = case_when(
    ts_account != 1 & con_sp_world == 1 ~ 1,
    i24 == 1 ~ 0,
    TRUE ~ NA_real_
  )) %>%
  filter(i24 == 1, regionwb24_hi == "High income") %>%
  summarise(val = weighted.mean(unbanked_sp_all, wgt_globalgfii, na.rm = TRUE)) %>%
  pull(val)

# Prepare data
plot_data <- data %>%
  filter(group == "all", year == 2024) %>%
  filter(countrynewwb %in% c_list_agg) %>%
  filter(aggregate_level == "region_all") %>%
  mutate(
    unbanked = 1 - ts_account,
    smart_shade = if_else(countrynewwb == "High income", hi_smart_value, con_smartP_ub),
    smart_shade = pmin(smart_shade, unbanked),  # avoid negative values
    grey_part = unbanked - smart_shade
  ) %>%
  select(countrynewwb, unbanked, smart_shade, grey_part) %>%
  pivot_longer(cols = c("grey_part", "smart_shade"), names_to = "segment", values_to = "value") %>%
  mutate(
    value = value * 100,
    segment = factor(segment, levels = c("grey_part", "smart_shade"),
                     labels = c("Unbanked adults who do not own a smartphone", 
                                "Unbanked adults who own a smartphone")),
    countrynewwb = recode(countrynewwb, !!!legend_labels),
    countrynewwb = factor(countrynewwb, levels = rev(unname(legend_labels)))
  )

# Plot
p <- ggplot(plot_data, aes(x = countrynewwb, y = value, fill = segment)) +
  geom_bar(stat = "identity", position = "stack", width = 0.6, color = "black", size = 0.5) +
  scale_fill_manual(
    values = c(
      "Unbanked adults who do not own a smartphone" = "#E6E6E6",
      "Unbanked adults who own a smartphone" = "#0F72BC"
    ),
    breaks = c("Unbanked adults who own a smartphone", 
               "Unbanked adults who do not own a smartphone")  # Reverse legend order
  ) +
  scale_y_continuous(
    limits = c(0, 70),
    breaks = seq(0, 100, by = 20),
    labels = function(x) x  # ??? no percent sign
  ) +
  coord_flip() +
  theme_minimal(base_family = "Nunito Sans") +
  theme(
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(size = 18, color = "black"),
    axis.text.y = element_text(size = 18, color = "black"),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.text = element_text(size = 18),
    plot.title = element_text(size = 26, face = "bold", hjust = 0),
    plot.subtitle = element_text(size = 22, hjust = 0),
    plot.caption = element_text(size = 18, hjust = -0.7, color = "black")
  ) +
  labs(
    title = "Unbanked adults who own a smartphone",
    subtitle = "Adults with no account (%), 2024",
    caption = "Source: Global Findex Database 2025"
  ) +
  guides(fill = guide_legend(nrow = 2, byrow = TRUE))

# Show plot
p

# Save plot
ggsave(
  filename = file.path(folder_path, "2.2.7.png"),
  plot = p,
  width = 10,
  height = 5,
  units = "in",
  dpi = 120
)
